Class: Google::Cloud::Storage::Control::V2::CreateRapidCacheMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Message returned in the metadata field of the Operation resource for CreateRapidCache operations.

Instance Attribute Summary collapse

Instance Attribute Details

#admission_policy::String

Returns Anywhere Cache entry Admission Policy in kebab-case (e.g., "admit-on-first-miss"). Default admission policy (admit-on-first-miss) is applied if not specified in the create request.

Returns:

  • (::String)

    Anywhere Cache entry Admission Policy in kebab-case (e.g., "admit-on-first-miss"). Default admission policy (admit-on-first-miss) is applied if not specified in the create request.



645
646
647
648
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 645

class CreateRapidCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#cache_type::String

Returns Optional. The type of cache. Either rapid cache or rapid cache ultra.

Returns:

  • (::String)

    Optional. The type of cache. Either rapid cache or rapid cache ultra.



645
646
647
648
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 645

class CreateRapidCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#common_metadata::Google::Cloud::Storage::Control::V2::CommonLongRunningOperationMetadata

Returns Generic metadata for the long running operation.

Returns:



645
646
647
648
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 645

class CreateRapidCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ingest_on_write::Boolean

Returns Optional. Specifies whether objects are ingested into the cache upon write. Defaults to false.

Returns:

  • (::Boolean)

    Optional. Specifies whether objects are ingested into the cache upon write. Defaults to false.



645
646
647
648
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 645

class CreateRapidCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rapid_cache_id::String

Returns Rapid Cache ID.

Returns:

  • (::String)

    Rapid Cache ID.



645
646
647
648
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 645

class CreateRapidCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ttl::Google::Protobuf::Duration

Returns Rapid Cache entry's TTL. A cache-level config that is applied to all new cache entries on admission. Default ttl value (24hrs) is applied if not specified in the create request.

Returns:

  • (::Google::Protobuf::Duration)

    Rapid Cache entry's TTL. A cache-level config that is applied to all new cache entries on admission. Default ttl value (24hrs) is applied if not specified in the create request.



645
646
647
648
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 645

class CreateRapidCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zone::String

Returns The zone in which the cache instance is running. For example, us-central1-a.

Returns:

  • (::String)

    The zone in which the cache instance is running. For example, us-central1-a.



645
646
647
648
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 645

class CreateRapidCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end