Class: Google::Cloud::Storage::Control::V2::CreateRapidCacheRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Request message for CreateRapidCache.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The bucket to which this cache belongs. Format: projects/{project}/buckets/{bucket}.

Returns:

  • (::String)

    Required. The bucket to which this cache belongs. Format: projects/{project}/buckets/{bucket}



961
962
963
964
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 961

class CreateRapidCacheRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rapid_cache::Google::Cloud::Storage::Control::V2::RapidCache

Returns Required. The RapidCache to create. Default values for ingest_on_write, ttl and admission_policy will be applied if not specified in the request.

Returns:



961
962
963
964
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 961

class CreateRapidCacheRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. A unique identifier for this request. UUID is the recommended format, but other formats are still accepted. This request is only idempotent if a request_id is provided.

Returns:

  • (::String)

    Optional. A unique identifier for this request. UUID is the recommended format, but other formats are still accepted. This request is only idempotent if a request_id is provided.



961
962
963
964
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 961

class CreateRapidCacheRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end