Class: Google::Cloud::Storage::Control::V2::DeleteFolderRecursiveRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Storage::Control::V2::DeleteFolderRecursiveRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/storage/control/v2/storage_control.rb
Overview
Request message for DeleteFolderRecursive.
Instance Attribute Summary collapse
-
#if_metageneration_match ⇒ ::Integer
Optional.
-
#if_metageneration_not_match ⇒ ::Integer
Optional.
-
#name ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#if_metageneration_match ⇒ ::Integer
Returns Optional. Makes the operation only succeed conditional on whether the root folder's current metageneration matches the given value.
242 243 244 245 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 242 class DeleteFolderRecursiveRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#if_metageneration_not_match ⇒ ::Integer
Returns Optional. Makes the operation only succeed conditional on whether the root folder's current metageneration does not match the given value.
242 243 244 245 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 242 class DeleteFolderRecursiveRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. Name of the folder being deleted, however all of its contents
will be deleted too. Format:
projects/{project}/buckets/{bucket}/folders/{folder}.
242 243 244 245 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 242 class DeleteFolderRecursiveRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. A unique identifier for this request. UUID is the recommended format, but other formats are still accepted.
242 243 244 245 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 242 class DeleteFolderRecursiveRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |