Class: Google::Cloud::Storage::Control::V2::IntelligenceConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

The IntelligenceConfig resource associated with your organization, folder, or project.

Defined Under Namespace

Modules: EditionConfig Classes: EffectiveIntelligenceConfig, Filter, TrialConfig

Instance Attribute Summary collapse

Instance Attribute Details

#edition_config::Google::Cloud::Storage::Control::V2::IntelligenceConfig::EditionConfig

Returns Optional. The edition configuration of the IntelligenceConfig resource.

Returns:



1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1070

class IntelligenceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Filter over location and bucket using include or exclude semantics.
  # Resources that match the include or exclude filter are exclusively included
  # or excluded from the Storage Intelligence plan.
  # @!attribute [rw] included_cloud_storage_locations
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageLocations]
  #     Bucket locations to include.
  #
  #     Note: The following fields are mutually exclusive: `included_cloud_storage_locations`, `excluded_cloud_storage_locations`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] excluded_cloud_storage_locations
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageLocations]
  #     Bucket locations to exclude.
  #
  #     Note: The following fields are mutually exclusive: `excluded_cloud_storage_locations`, `included_cloud_storage_locations`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] included_cloud_storage_buckets
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageBuckets]
  #     Buckets to include.
  #
  #     Note: The following fields are mutually exclusive: `included_cloud_storage_buckets`, `excluded_cloud_storage_buckets`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] excluded_cloud_storage_buckets
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageBuckets]
  #     Buckets to exclude.
  #
  #     Note: The following fields are mutually exclusive: `excluded_cloud_storage_buckets`, `included_cloud_storage_buckets`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class Filter
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Collection of bucket locations.
    # @!attribute [rw] locations
    #   @return [::Array<::String>]
    #     Optional. Bucket locations. Location can be any of the Cloud Storage
    #     regions specified in lower case format. For example, `us-east1`,
    #     `us-west1`.
    class CloudStorageLocations
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Collection of buckets.
    # @!attribute [rw] bucket_id_regexes
    #   @return [::Array<::String>]
    #     Optional. A regex pattern for matching bucket names. Regex should
    #     follow the syntax specified in
    #     [google/re2](https://github.com/google/re2). For example,
    #     `^sample_.*` matches all buckets of the form
    #     `gs://sample_bucket-1`, `gs://sample_bucket-2`,
    #     `gs://sample_bucket-n` but not `gs://test_sample_bucket`.
    #     If you want to match a single bucket, say `gs://sample_bucket`,
    #     use `sample_bucket`.
    class CloudStorageBuckets
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # The effective `IntelligenceConfig` for the resource.
  # @!attribute [r] effective_edition
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::EffectiveIntelligenceConfig::EffectiveEdition]
  #     Output only. The `IntelligenceConfig` edition that is applicable for the
  #     resource.
  # @!attribute [r] intelligence_config
  #   @return [::String]
  #     Output only. The `IntelligenceConfig` resource that is applied for the
  #     target resource. Format:
  #     `{organizations|folders|projects}/{id}/locations/{location}/intelligenceConfig`
  class EffectiveIntelligenceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The effective edition of the `IntelligenceConfig` resource.
    module EffectiveEdition
      # This is an unknown edition of the resource.
      EFFECTIVE_EDITION_UNSPECIFIED = 0

      # No edition.
      NONE = 1

      # The `IntelligenceConfig` resource is of STANDARD edition.
      STANDARD = 2
    end
  end

  # The trial configuration of the `IntelligenceConfig` resource.
  # @!attribute [r] expire_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time at which the trial expires.
  class TrialConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The edition configuration of the `IntelligenceConfig` resource. This
  # signifies the edition used for configuring the `IntelligenceConfig`
  # resource and can only take the following values:
  # `EDITION_CONFIG_UNSPECIFIED`, `INHERIT`, `DISABLED`, `STANDARD` and
  # `EVALUATE`.
  module EditionConfig
    # This is an unknown edition of the resource.
    EDITION_CONFIG_UNSPECIFIED = 0

    # The inherited edition from the parent and filters. This is the default
    # edition when there is no `IntelligenceConfig` setup for a GCP resource.
    INHERIT = 1

    # The edition configuration is disabled for the `IntelligenceConfig`
    # resource and its children. Filters are not applicable.
    DISABLED = 2

    # The `IntelligenceConfig` resource is of STANDARD edition.
    STANDARD = 3

    # The `IntelligenceConfig` resource is available in `TRIAL` edition. During
    # the trial period, Cloud Storage does not charge for Storage Intelligence
    # usage. You can specify the buckets to include in the trial period by
    # using filters. At the end of the trial period, the `IntelligenceConfig`
    # resource is upgraded to `STANDARD` edition.
    TRIAL = 5

    # The `IntelligenceConfig` resource is of ESSENTIALS edition.
    ESSENTIALS = 6
  end
end

#effective_intelligence_config::Google::Cloud::Storage::Control::V2::IntelligenceConfig::EffectiveIntelligenceConfig (readonly)

Returns Output only. The IntelligenceConfig resource that is applicable for the resource.

Returns:



1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1070

class IntelligenceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Filter over location and bucket using include or exclude semantics.
  # Resources that match the include or exclude filter are exclusively included
  # or excluded from the Storage Intelligence plan.
  # @!attribute [rw] included_cloud_storage_locations
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageLocations]
  #     Bucket locations to include.
  #
  #     Note: The following fields are mutually exclusive: `included_cloud_storage_locations`, `excluded_cloud_storage_locations`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] excluded_cloud_storage_locations
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageLocations]
  #     Bucket locations to exclude.
  #
  #     Note: The following fields are mutually exclusive: `excluded_cloud_storage_locations`, `included_cloud_storage_locations`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] included_cloud_storage_buckets
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageBuckets]
  #     Buckets to include.
  #
  #     Note: The following fields are mutually exclusive: `included_cloud_storage_buckets`, `excluded_cloud_storage_buckets`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] excluded_cloud_storage_buckets
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageBuckets]
  #     Buckets to exclude.
  #
  #     Note: The following fields are mutually exclusive: `excluded_cloud_storage_buckets`, `included_cloud_storage_buckets`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class Filter
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Collection of bucket locations.
    # @!attribute [rw] locations
    #   @return [::Array<::String>]
    #     Optional. Bucket locations. Location can be any of the Cloud Storage
    #     regions specified in lower case format. For example, `us-east1`,
    #     `us-west1`.
    class CloudStorageLocations
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Collection of buckets.
    # @!attribute [rw] bucket_id_regexes
    #   @return [::Array<::String>]
    #     Optional. A regex pattern for matching bucket names. Regex should
    #     follow the syntax specified in
    #     [google/re2](https://github.com/google/re2). For example,
    #     `^sample_.*` matches all buckets of the form
    #     `gs://sample_bucket-1`, `gs://sample_bucket-2`,
    #     `gs://sample_bucket-n` but not `gs://test_sample_bucket`.
    #     If you want to match a single bucket, say `gs://sample_bucket`,
    #     use `sample_bucket`.
    class CloudStorageBuckets
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # The effective `IntelligenceConfig` for the resource.
  # @!attribute [r] effective_edition
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::EffectiveIntelligenceConfig::EffectiveEdition]
  #     Output only. The `IntelligenceConfig` edition that is applicable for the
  #     resource.
  # @!attribute [r] intelligence_config
  #   @return [::String]
  #     Output only. The `IntelligenceConfig` resource that is applied for the
  #     target resource. Format:
  #     `{organizations|folders|projects}/{id}/locations/{location}/intelligenceConfig`
  class EffectiveIntelligenceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The effective edition of the `IntelligenceConfig` resource.
    module EffectiveEdition
      # This is an unknown edition of the resource.
      EFFECTIVE_EDITION_UNSPECIFIED = 0

      # No edition.
      NONE = 1

      # The `IntelligenceConfig` resource is of STANDARD edition.
      STANDARD = 2
    end
  end

  # The trial configuration of the `IntelligenceConfig` resource.
  # @!attribute [r] expire_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time at which the trial expires.
  class TrialConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The edition configuration of the `IntelligenceConfig` resource. This
  # signifies the edition used for configuring the `IntelligenceConfig`
  # resource and can only take the following values:
  # `EDITION_CONFIG_UNSPECIFIED`, `INHERIT`, `DISABLED`, `STANDARD` and
  # `EVALUATE`.
  module EditionConfig
    # This is an unknown edition of the resource.
    EDITION_CONFIG_UNSPECIFIED = 0

    # The inherited edition from the parent and filters. This is the default
    # edition when there is no `IntelligenceConfig` setup for a GCP resource.
    INHERIT = 1

    # The edition configuration is disabled for the `IntelligenceConfig`
    # resource and its children. Filters are not applicable.
    DISABLED = 2

    # The `IntelligenceConfig` resource is of STANDARD edition.
    STANDARD = 3

    # The `IntelligenceConfig` resource is available in `TRIAL` edition. During
    # the trial period, Cloud Storage does not charge for Storage Intelligence
    # usage. You can specify the buckets to include in the trial period by
    # using filters. At the end of the trial period, the `IntelligenceConfig`
    # resource is upgraded to `STANDARD` edition.
    TRIAL = 5

    # The `IntelligenceConfig` resource is of ESSENTIALS edition.
    ESSENTIALS = 6
  end
end

#filter::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter

Returns Optional. Filter over location and bucket.

Returns:



1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1070

class IntelligenceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Filter over location and bucket using include or exclude semantics.
  # Resources that match the include or exclude filter are exclusively included
  # or excluded from the Storage Intelligence plan.
  # @!attribute [rw] included_cloud_storage_locations
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageLocations]
  #     Bucket locations to include.
  #
  #     Note: The following fields are mutually exclusive: `included_cloud_storage_locations`, `excluded_cloud_storage_locations`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] excluded_cloud_storage_locations
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageLocations]
  #     Bucket locations to exclude.
  #
  #     Note: The following fields are mutually exclusive: `excluded_cloud_storage_locations`, `included_cloud_storage_locations`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] included_cloud_storage_buckets
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageBuckets]
  #     Buckets to include.
  #
  #     Note: The following fields are mutually exclusive: `included_cloud_storage_buckets`, `excluded_cloud_storage_buckets`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] excluded_cloud_storage_buckets
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageBuckets]
  #     Buckets to exclude.
  #
  #     Note: The following fields are mutually exclusive: `excluded_cloud_storage_buckets`, `included_cloud_storage_buckets`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class Filter
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Collection of bucket locations.
    # @!attribute [rw] locations
    #   @return [::Array<::String>]
    #     Optional. Bucket locations. Location can be any of the Cloud Storage
    #     regions specified in lower case format. For example, `us-east1`,
    #     `us-west1`.
    class CloudStorageLocations
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Collection of buckets.
    # @!attribute [rw] bucket_id_regexes
    #   @return [::Array<::String>]
    #     Optional. A regex pattern for matching bucket names. Regex should
    #     follow the syntax specified in
    #     [google/re2](https://github.com/google/re2). For example,
    #     `^sample_.*` matches all buckets of the form
    #     `gs://sample_bucket-1`, `gs://sample_bucket-2`,
    #     `gs://sample_bucket-n` but not `gs://test_sample_bucket`.
    #     If you want to match a single bucket, say `gs://sample_bucket`,
    #     use `sample_bucket`.
    class CloudStorageBuckets
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # The effective `IntelligenceConfig` for the resource.
  # @!attribute [r] effective_edition
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::EffectiveIntelligenceConfig::EffectiveEdition]
  #     Output only. The `IntelligenceConfig` edition that is applicable for the
  #     resource.
  # @!attribute [r] intelligence_config
  #   @return [::String]
  #     Output only. The `IntelligenceConfig` resource that is applied for the
  #     target resource. Format:
  #     `{organizations|folders|projects}/{id}/locations/{location}/intelligenceConfig`
  class EffectiveIntelligenceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The effective edition of the `IntelligenceConfig` resource.
    module EffectiveEdition
      # This is an unknown edition of the resource.
      EFFECTIVE_EDITION_UNSPECIFIED = 0

      # No edition.
      NONE = 1

      # The `IntelligenceConfig` resource is of STANDARD edition.
      STANDARD = 2
    end
  end

  # The trial configuration of the `IntelligenceConfig` resource.
  # @!attribute [r] expire_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time at which the trial expires.
  class TrialConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The edition configuration of the `IntelligenceConfig` resource. This
  # signifies the edition used for configuring the `IntelligenceConfig`
  # resource and can only take the following values:
  # `EDITION_CONFIG_UNSPECIFIED`, `INHERIT`, `DISABLED`, `STANDARD` and
  # `EVALUATE`.
  module EditionConfig
    # This is an unknown edition of the resource.
    EDITION_CONFIG_UNSPECIFIED = 0

    # The inherited edition from the parent and filters. This is the default
    # edition when there is no `IntelligenceConfig` setup for a GCP resource.
    INHERIT = 1

    # The edition configuration is disabled for the `IntelligenceConfig`
    # resource and its children. Filters are not applicable.
    DISABLED = 2

    # The `IntelligenceConfig` resource is of STANDARD edition.
    STANDARD = 3

    # The `IntelligenceConfig` resource is available in `TRIAL` edition. During
    # the trial period, Cloud Storage does not charge for Storage Intelligence
    # usage. You can specify the buckets to include in the trial period by
    # using filters. At the end of the trial period, the `IntelligenceConfig`
    # resource is upgraded to `STANDARD` edition.
    TRIAL = 5

    # The `IntelligenceConfig` resource is of ESSENTIALS edition.
    ESSENTIALS = 6
  end
end

#name::String

Returns Identifier. The name of the IntelligenceConfig resource associated with your organization, folder, or project.

The name format varies based on the GCP resource hierarchy as follows:

  • For project: projects/{project_number}/locations/global/intelligenceConfig
  • For organization: organizations/{org_id}/locations/global/intelligenceConfig
  • For folder: folders/{folder_id}/locations/global/intelligenceConfig.

Returns:

  • (::String)

    Identifier. The name of the IntelligenceConfig resource associated with your organization, folder, or project.

    The name format varies based on the GCP resource hierarchy as follows:

    • For project: projects/{project_number}/locations/global/intelligenceConfig
    • For organization: organizations/{org_id}/locations/global/intelligenceConfig
    • For folder: folders/{folder_id}/locations/global/intelligenceConfig


1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1070

class IntelligenceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Filter over location and bucket using include or exclude semantics.
  # Resources that match the include or exclude filter are exclusively included
  # or excluded from the Storage Intelligence plan.
  # @!attribute [rw] included_cloud_storage_locations
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageLocations]
  #     Bucket locations to include.
  #
  #     Note: The following fields are mutually exclusive: `included_cloud_storage_locations`, `excluded_cloud_storage_locations`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] excluded_cloud_storage_locations
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageLocations]
  #     Bucket locations to exclude.
  #
  #     Note: The following fields are mutually exclusive: `excluded_cloud_storage_locations`, `included_cloud_storage_locations`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] included_cloud_storage_buckets
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageBuckets]
  #     Buckets to include.
  #
  #     Note: The following fields are mutually exclusive: `included_cloud_storage_buckets`, `excluded_cloud_storage_buckets`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] excluded_cloud_storage_buckets
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageBuckets]
  #     Buckets to exclude.
  #
  #     Note: The following fields are mutually exclusive: `excluded_cloud_storage_buckets`, `included_cloud_storage_buckets`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class Filter
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Collection of bucket locations.
    # @!attribute [rw] locations
    #   @return [::Array<::String>]
    #     Optional. Bucket locations. Location can be any of the Cloud Storage
    #     regions specified in lower case format. For example, `us-east1`,
    #     `us-west1`.
    class CloudStorageLocations
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Collection of buckets.
    # @!attribute [rw] bucket_id_regexes
    #   @return [::Array<::String>]
    #     Optional. A regex pattern for matching bucket names. Regex should
    #     follow the syntax specified in
    #     [google/re2](https://github.com/google/re2). For example,
    #     `^sample_.*` matches all buckets of the form
    #     `gs://sample_bucket-1`, `gs://sample_bucket-2`,
    #     `gs://sample_bucket-n` but not `gs://test_sample_bucket`.
    #     If you want to match a single bucket, say `gs://sample_bucket`,
    #     use `sample_bucket`.
    class CloudStorageBuckets
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # The effective `IntelligenceConfig` for the resource.
  # @!attribute [r] effective_edition
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::EffectiveIntelligenceConfig::EffectiveEdition]
  #     Output only. The `IntelligenceConfig` edition that is applicable for the
  #     resource.
  # @!attribute [r] intelligence_config
  #   @return [::String]
  #     Output only. The `IntelligenceConfig` resource that is applied for the
  #     target resource. Format:
  #     `{organizations|folders|projects}/{id}/locations/{location}/intelligenceConfig`
  class EffectiveIntelligenceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The effective edition of the `IntelligenceConfig` resource.
    module EffectiveEdition
      # This is an unknown edition of the resource.
      EFFECTIVE_EDITION_UNSPECIFIED = 0

      # No edition.
      NONE = 1

      # The `IntelligenceConfig` resource is of STANDARD edition.
      STANDARD = 2
    end
  end

  # The trial configuration of the `IntelligenceConfig` resource.
  # @!attribute [r] expire_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time at which the trial expires.
  class TrialConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The edition configuration of the `IntelligenceConfig` resource. This
  # signifies the edition used for configuring the `IntelligenceConfig`
  # resource and can only take the following values:
  # `EDITION_CONFIG_UNSPECIFIED`, `INHERIT`, `DISABLED`, `STANDARD` and
  # `EVALUATE`.
  module EditionConfig
    # This is an unknown edition of the resource.
    EDITION_CONFIG_UNSPECIFIED = 0

    # The inherited edition from the parent and filters. This is the default
    # edition when there is no `IntelligenceConfig` setup for a GCP resource.
    INHERIT = 1

    # The edition configuration is disabled for the `IntelligenceConfig`
    # resource and its children. Filters are not applicable.
    DISABLED = 2

    # The `IntelligenceConfig` resource is of STANDARD edition.
    STANDARD = 3

    # The `IntelligenceConfig` resource is available in `TRIAL` edition. During
    # the trial period, Cloud Storage does not charge for Storage Intelligence
    # usage. You can specify the buckets to include in the trial period by
    # using filters. At the end of the trial period, the `IntelligenceConfig`
    # resource is upgraded to `STANDARD` edition.
    TRIAL = 5

    # The `IntelligenceConfig` resource is of ESSENTIALS edition.
    ESSENTIALS = 6
  end
end

#trial_config::Google::Cloud::Storage::Control::V2::IntelligenceConfig::TrialConfig

Returns The trial configuration of the IntelligenceConfig resource.

Returns:



1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1070

class IntelligenceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Filter over location and bucket using include or exclude semantics.
  # Resources that match the include or exclude filter are exclusively included
  # or excluded from the Storage Intelligence plan.
  # @!attribute [rw] included_cloud_storage_locations
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageLocations]
  #     Bucket locations to include.
  #
  #     Note: The following fields are mutually exclusive: `included_cloud_storage_locations`, `excluded_cloud_storage_locations`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] excluded_cloud_storage_locations
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageLocations]
  #     Bucket locations to exclude.
  #
  #     Note: The following fields are mutually exclusive: `excluded_cloud_storage_locations`, `included_cloud_storage_locations`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] included_cloud_storage_buckets
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageBuckets]
  #     Buckets to include.
  #
  #     Note: The following fields are mutually exclusive: `included_cloud_storage_buckets`, `excluded_cloud_storage_buckets`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] excluded_cloud_storage_buckets
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageBuckets]
  #     Buckets to exclude.
  #
  #     Note: The following fields are mutually exclusive: `excluded_cloud_storage_buckets`, `included_cloud_storage_buckets`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class Filter
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Collection of bucket locations.
    # @!attribute [rw] locations
    #   @return [::Array<::String>]
    #     Optional. Bucket locations. Location can be any of the Cloud Storage
    #     regions specified in lower case format. For example, `us-east1`,
    #     `us-west1`.
    class CloudStorageLocations
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Collection of buckets.
    # @!attribute [rw] bucket_id_regexes
    #   @return [::Array<::String>]
    #     Optional. A regex pattern for matching bucket names. Regex should
    #     follow the syntax specified in
    #     [google/re2](https://github.com/google/re2). For example,
    #     `^sample_.*` matches all buckets of the form
    #     `gs://sample_bucket-1`, `gs://sample_bucket-2`,
    #     `gs://sample_bucket-n` but not `gs://test_sample_bucket`.
    #     If you want to match a single bucket, say `gs://sample_bucket`,
    #     use `sample_bucket`.
    class CloudStorageBuckets
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # The effective `IntelligenceConfig` for the resource.
  # @!attribute [r] effective_edition
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::EffectiveIntelligenceConfig::EffectiveEdition]
  #     Output only. The `IntelligenceConfig` edition that is applicable for the
  #     resource.
  # @!attribute [r] intelligence_config
  #   @return [::String]
  #     Output only. The `IntelligenceConfig` resource that is applied for the
  #     target resource. Format:
  #     `{organizations|folders|projects}/{id}/locations/{location}/intelligenceConfig`
  class EffectiveIntelligenceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The effective edition of the `IntelligenceConfig` resource.
    module EffectiveEdition
      # This is an unknown edition of the resource.
      EFFECTIVE_EDITION_UNSPECIFIED = 0

      # No edition.
      NONE = 1

      # The `IntelligenceConfig` resource is of STANDARD edition.
      STANDARD = 2
    end
  end

  # The trial configuration of the `IntelligenceConfig` resource.
  # @!attribute [r] expire_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time at which the trial expires.
  class TrialConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The edition configuration of the `IntelligenceConfig` resource. This
  # signifies the edition used for configuring the `IntelligenceConfig`
  # resource and can only take the following values:
  # `EDITION_CONFIG_UNSPECIFIED`, `INHERIT`, `DISABLED`, `STANDARD` and
  # `EVALUATE`.
  module EditionConfig
    # This is an unknown edition of the resource.
    EDITION_CONFIG_UNSPECIFIED = 0

    # The inherited edition from the parent and filters. This is the default
    # edition when there is no `IntelligenceConfig` setup for a GCP resource.
    INHERIT = 1

    # The edition configuration is disabled for the `IntelligenceConfig`
    # resource and its children. Filters are not applicable.
    DISABLED = 2

    # The `IntelligenceConfig` resource is of STANDARD edition.
    STANDARD = 3

    # The `IntelligenceConfig` resource is available in `TRIAL` edition. During
    # the trial period, Cloud Storage does not charge for Storage Intelligence
    # usage. You can specify the buckets to include in the trial period by
    # using filters. At the end of the trial period, the `IntelligenceConfig`
    # resource is upgraded to `STANDARD` edition.
    TRIAL = 5

    # The `IntelligenceConfig` resource is of ESSENTIALS edition.
    ESSENTIALS = 6
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the IntelligenceConfig resource is last updated.

Returns:



1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1070

class IntelligenceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Filter over location and bucket using include or exclude semantics.
  # Resources that match the include or exclude filter are exclusively included
  # or excluded from the Storage Intelligence plan.
  # @!attribute [rw] included_cloud_storage_locations
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageLocations]
  #     Bucket locations to include.
  #
  #     Note: The following fields are mutually exclusive: `included_cloud_storage_locations`, `excluded_cloud_storage_locations`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] excluded_cloud_storage_locations
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageLocations]
  #     Bucket locations to exclude.
  #
  #     Note: The following fields are mutually exclusive: `excluded_cloud_storage_locations`, `included_cloud_storage_locations`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] included_cloud_storage_buckets
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageBuckets]
  #     Buckets to include.
  #
  #     Note: The following fields are mutually exclusive: `included_cloud_storage_buckets`, `excluded_cloud_storage_buckets`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] excluded_cloud_storage_buckets
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::Filter::CloudStorageBuckets]
  #     Buckets to exclude.
  #
  #     Note: The following fields are mutually exclusive: `excluded_cloud_storage_buckets`, `included_cloud_storage_buckets`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class Filter
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Collection of bucket locations.
    # @!attribute [rw] locations
    #   @return [::Array<::String>]
    #     Optional. Bucket locations. Location can be any of the Cloud Storage
    #     regions specified in lower case format. For example, `us-east1`,
    #     `us-west1`.
    class CloudStorageLocations
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Collection of buckets.
    # @!attribute [rw] bucket_id_regexes
    #   @return [::Array<::String>]
    #     Optional. A regex pattern for matching bucket names. Regex should
    #     follow the syntax specified in
    #     [google/re2](https://github.com/google/re2). For example,
    #     `^sample_.*` matches all buckets of the form
    #     `gs://sample_bucket-1`, `gs://sample_bucket-2`,
    #     `gs://sample_bucket-n` but not `gs://test_sample_bucket`.
    #     If you want to match a single bucket, say `gs://sample_bucket`,
    #     use `sample_bucket`.
    class CloudStorageBuckets
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # The effective `IntelligenceConfig` for the resource.
  # @!attribute [r] effective_edition
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceConfig::EffectiveIntelligenceConfig::EffectiveEdition]
  #     Output only. The `IntelligenceConfig` edition that is applicable for the
  #     resource.
  # @!attribute [r] intelligence_config
  #   @return [::String]
  #     Output only. The `IntelligenceConfig` resource that is applied for the
  #     target resource. Format:
  #     `{organizations|folders|projects}/{id}/locations/{location}/intelligenceConfig`
  class EffectiveIntelligenceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The effective edition of the `IntelligenceConfig` resource.
    module EffectiveEdition
      # This is an unknown edition of the resource.
      EFFECTIVE_EDITION_UNSPECIFIED = 0

      # No edition.
      NONE = 1

      # The `IntelligenceConfig` resource is of STANDARD edition.
      STANDARD = 2
    end
  end

  # The trial configuration of the `IntelligenceConfig` resource.
  # @!attribute [r] expire_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time at which the trial expires.
  class TrialConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The edition configuration of the `IntelligenceConfig` resource. This
  # signifies the edition used for configuring the `IntelligenceConfig`
  # resource and can only take the following values:
  # `EDITION_CONFIG_UNSPECIFIED`, `INHERIT`, `DISABLED`, `STANDARD` and
  # `EVALUATE`.
  module EditionConfig
    # This is an unknown edition of the resource.
    EDITION_CONFIG_UNSPECIFIED = 0

    # The inherited edition from the parent and filters. This is the default
    # edition when there is no `IntelligenceConfig` setup for a GCP resource.
    INHERIT = 1

    # The edition configuration is disabled for the `IntelligenceConfig`
    # resource and its children. Filters are not applicable.
    DISABLED = 2

    # The `IntelligenceConfig` resource is of STANDARD edition.
    STANDARD = 3

    # The `IntelligenceConfig` resource is available in `TRIAL` edition. During
    # the trial period, Cloud Storage does not charge for Storage Intelligence
    # usage. You can specify the buckets to include in the trial period by
    # using filters. At the end of the trial period, the `IntelligenceConfig`
    # resource is upgraded to `STANDARD` edition.
    TRIAL = 5

    # The `IntelligenceConfig` resource is of ESSENTIALS edition.
    ESSENTIALS = 6
  end
end