Class: Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Represents a finding about a spike in Class A/B operations on Coldline or Archive Cloud Storage objects. This corresponds to the COLD_AND_ARCHIVAL_STORAGE_OPERATIONS_SPIKE finding type.

Defined Under Namespace

Classes: BucketContribution

Instance Attribute Summary collapse

Instance Attribute Details

#percentage_increase::Float (readonly)

Returns Output only. The percentage increase in operations across the project.

Returns:

  • (::Float)

    Output only. The percentage increase in operations across the project.



1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1376

class ColdlineAndArchivalStorageOperationsSpike
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the operation spike details for a bucket.
  # @!attribute [r] bucket
  #   @return [::String]
  #     Output only. The name of the bucket.
  # @!attribute [r] percentage_increase
  #   @return [::Float]
  #     Output only. The percentage increase in operations for the bucket.
  # @!attribute [r] total_operations_count
  #   @return [::Integer]
  #     Output only. The total count of operations for the bucket.
  # @!attribute [r] contribution
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution]
  #     Output only. The details about the contribution of the bucket.
  #
  #     Note: The following fields are mutually exclusive: `contribution`, `error`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] error
  #   @return [::Google::Rpc::Status]
  #     Output only. The error related to accessing the details about the
  #     contribution of the bucket.
  #
  #     Note: The following fields are mutually exclusive: `error`, `contribution`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class BucketContribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the contribution of the bucket towards the
    # `IntelligenceFinding`.
    # @!attribute [r] top_prefixes
    #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution::PrefixContribution>]
    #     Output only. A list of the top object prefixes driving the increase
    #     in operations.
    class Contribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # Represents the operation spike details for an object prefix.
      # @!attribute [r] prefix
      #   @return [::String]
      #     Output only. The object prefix.
      #     Format: `a/b/c`, 'a/b/d', etc.
      # @!attribute [r] percentage_increase
      #   @return [::Float]
      #     Output only. The percentage increase in operations for the object
      #     prefix.
      # @!attribute [r] total_operations_count
      #   @return [::Integer]
      #     Output only. The total count of operations for the object prefix.
      class PrefixContribution
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods
      end
    end
  end
end

#top_buckets::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution> (readonly)

Returns Output only. A list of the top buckets driving the increase in operations.

Returns:



1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1376

class ColdlineAndArchivalStorageOperationsSpike
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the operation spike details for a bucket.
  # @!attribute [r] bucket
  #   @return [::String]
  #     Output only. The name of the bucket.
  # @!attribute [r] percentage_increase
  #   @return [::Float]
  #     Output only. The percentage increase in operations for the bucket.
  # @!attribute [r] total_operations_count
  #   @return [::Integer]
  #     Output only. The total count of operations for the bucket.
  # @!attribute [r] contribution
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution]
  #     Output only. The details about the contribution of the bucket.
  #
  #     Note: The following fields are mutually exclusive: `contribution`, `error`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] error
  #   @return [::Google::Rpc::Status]
  #     Output only. The error related to accessing the details about the
  #     contribution of the bucket.
  #
  #     Note: The following fields are mutually exclusive: `error`, `contribution`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class BucketContribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the contribution of the bucket towards the
    # `IntelligenceFinding`.
    # @!attribute [r] top_prefixes
    #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution::PrefixContribution>]
    #     Output only. A list of the top object prefixes driving the increase
    #     in operations.
    class Contribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # Represents the operation spike details for an object prefix.
      # @!attribute [r] prefix
      #   @return [::String]
      #     Output only. The object prefix.
      #     Format: `a/b/c`, 'a/b/d', etc.
      # @!attribute [r] percentage_increase
      #   @return [::Float]
      #     Output only. The percentage increase in operations for the object
      #     prefix.
      # @!attribute [r] total_operations_count
      #   @return [::Integer]
      #     Output only. The total count of operations for the object prefix.
      class PrefixContribution
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods
      end
    end
  end
end

#total_operations_count::Integer (readonly)

Returns Output only. The total count of operations across the project.

Returns:

  • (::Integer)

    Output only. The total count of operations across the project.



1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1376

class ColdlineAndArchivalStorageOperationsSpike
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the operation spike details for a bucket.
  # @!attribute [r] bucket
  #   @return [::String]
  #     Output only. The name of the bucket.
  # @!attribute [r] percentage_increase
  #   @return [::Float]
  #     Output only. The percentage increase in operations for the bucket.
  # @!attribute [r] total_operations_count
  #   @return [::Integer]
  #     Output only. The total count of operations for the bucket.
  # @!attribute [r] contribution
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution]
  #     Output only. The details about the contribution of the bucket.
  #
  #     Note: The following fields are mutually exclusive: `contribution`, `error`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] error
  #   @return [::Google::Rpc::Status]
  #     Output only. The error related to accessing the details about the
  #     contribution of the bucket.
  #
  #     Note: The following fields are mutually exclusive: `error`, `contribution`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class BucketContribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the contribution of the bucket towards the
    # `IntelligenceFinding`.
    # @!attribute [r] top_prefixes
    #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution::PrefixContribution>]
    #     Output only. A list of the top object prefixes driving the increase
    #     in operations.
    class Contribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # Represents the operation spike details for an object prefix.
      # @!attribute [r] prefix
      #   @return [::String]
      #     Output only. The object prefix.
      #     Format: `a/b/c`, 'a/b/d', etc.
      # @!attribute [r] percentage_increase
      #   @return [::Float]
      #     Output only. The percentage increase in operations for the object
      #     prefix.
      # @!attribute [r] total_operations_count
      #   @return [::Integer]
      #     Output only. The total count of operations for the object prefix.
      class PrefixContribution
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods
      end
    end
  end
end