Class: Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Represents the contribution of the bucket towards the IntelligenceFinding.

Defined Under Namespace

Classes: PrefixContribution

Instance Attribute Summary collapse

Instance Attribute Details

#top_prefixes::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution::PrefixContribution> (readonly)

Returns Output only. A list of the top object prefixes driving the increase in cross-region egress.

Returns:



1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1217

class Contribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the cross-region egress spike details for an object
  # prefix.
  # @!attribute [r] prefix
  #   @return [::String]
  #     Output only. The object prefix.
  #     Format: `a/b/c`, 'a/b/d', etc.
  # @!attribute [r] total_egress_bytes
  #   @return [::Integer]
  #     Output only. The total cross-region egress volume in bytes from the
  #     object prefix.
  # @!attribute [r] percentage_increase
  #   @return [::Float]
  #     Output only. The percentage increase in cross-region egress for the
  #     object prefix.
  class PrefixContribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end