Class: Google::Cloud::Storage::Control::V2::IntelligenceFinding::StorageGrowthAboveTrend

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Represents a finding about a storage growth above the expected trend. This corresponds to the STORAGE_GROWTH_ABOVE_TREND finding type.

Defined Under Namespace

Classes: BucketContribution

Instance Attribute Summary collapse

Instance Attribute Details

#percentage_increase::Float (readonly)

Returns Output only. The percentage increase in storage growth.

Returns:

  • (::Float)

    Output only. The percentage increase in storage growth.



1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1599

class StorageGrowthAboveTrend
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the storage growth details for a bucket.
  # @!attribute [r] bucket
  #   @return [::String]
  #     Output only. The name of the bucket.
  # @!attribute [r] total_storage_growth_bytes
  #   @return [::Integer]
  #     Output only. The total storage growth in bytes for the bucket.
  # @!attribute [r] percentage_increase
  #   @return [::Float]
  #     Output only. The percentage increase in storage growth for the bucket.
  # @!attribute [r] error
  #   @return [::Google::Rpc::Status]
  #     Output only. The error related to accessing the details about the
  #     contribution of the bucket.
  class BucketContribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#top_buckets::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::StorageGrowthAboveTrend::BucketContribution> (readonly)

Returns Output only. A list of top buckets driving the increase in storage growth.

Returns:



1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1599

class StorageGrowthAboveTrend
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the storage growth details for a bucket.
  # @!attribute [r] bucket
  #   @return [::String]
  #     Output only. The name of the bucket.
  # @!attribute [r] total_storage_growth_bytes
  #   @return [::Integer]
  #     Output only. The total storage growth in bytes for the bucket.
  # @!attribute [r] percentage_increase
  #   @return [::Float]
  #     Output only. The percentage increase in storage growth for the bucket.
  # @!attribute [r] error
  #   @return [::Google::Rpc::Status]
  #     Output only. The error related to accessing the details about the
  #     contribution of the bucket.
  class BucketContribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#total_storage_growth_bytes::Integer (readonly)

Returns Output only. The total storage growth in bytes.

Returns:

  • (::Integer)

    Output only. The total storage growth in bytes.



1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1599

class StorageGrowthAboveTrend
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the storage growth details for a bucket.
  # @!attribute [r] bucket
  #   @return [::String]
  #     Output only. The name of the bucket.
  # @!attribute [r] total_storage_growth_bytes
  #   @return [::Integer]
  #     Output only. The total storage growth in bytes for the bucket.
  # @!attribute [r] percentage_increase
  #   @return [::Float]
  #     Output only. The percentage increase in storage growth for the bucket.
  # @!attribute [r] error
  #   @return [::Google::Rpc::Status]
  #     Output only. The error related to accessing the details about the
  #     contribution of the bucket.
  class BucketContribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end