Class: Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Represents the throttled requests details for a bucket.

Defined Under Namespace

Classes: Contribution

Instance Attribute Summary collapse

Instance Attribute Details

#bucket::String (readonly)

Returns Output only. The name of the bucket.

Returns:

  • (::String)

    Output only. The name of the bucket.



1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1553

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of top object prefixes driving the increase in
  #     throttled requests.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents throttled requests details for an object prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] throttled_requests
    #   @return [::Integer]
    #     Output only. The count of throttled requests for the object prefix.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in throttled requests for the
    #     object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#contribution::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution (readonly)

Returns Output only. The details about the contribution of the bucket.

Note: The following fields are mutually exclusive: contribution, error. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1553

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of top object prefixes driving the increase in
  #     throttled requests.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents throttled requests details for an object prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] throttled_requests
    #   @return [::Integer]
    #     Output only. The count of throttled requests for the object prefix.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in throttled requests for the
    #     object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#error::Google::Rpc::Status (readonly)

Returns Output only. The error related to accessing the details about the contribution of the bucket.

Note: The following fields are mutually exclusive: error, contribution. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Rpc::Status)

    Output only. The error related to accessing the details about the contribution of the bucket.

    Note: The following fields are mutually exclusive: error, contribution. If a field in that set is populated, all other fields in the set will automatically be cleared.



1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1553

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of top object prefixes driving the increase in
  #     throttled requests.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents throttled requests details for an object prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] throttled_requests
    #   @return [::Integer]
    #     Output only. The count of throttled requests for the object prefix.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in throttled requests for the
    #     object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#percentage_increase::Float (readonly)

Returns Output only. The percentage increase in throttled requests for the bucket.

Returns:

  • (::Float)

    Output only. The percentage increase in throttled requests for the bucket.



1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1553

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of top object prefixes driving the increase in
  #     throttled requests.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents throttled requests details for an object prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] throttled_requests
    #   @return [::Integer]
    #     Output only. The count of throttled requests for the object prefix.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in throttled requests for the
    #     object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#throttled_requests::Integer (readonly)

Returns Output only. The count of throttled requests for the bucket.

Returns:

  • (::Integer)

    Output only. The count of throttled requests for the bucket.



1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1553

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of top object prefixes driving the increase in
  #     throttled requests.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents throttled requests details for an object prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] throttled_requests
    #   @return [::Integer]
    #     Output only. The count of throttled requests for the object prefix.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in throttled requests for the
    #     object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end