Class: Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution
- Inherits:
-
Object
- Object
- Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/storage/control/v2/storage_control.rb
Overview
Represents the contribution of the bucket towards the
IntelligenceFinding.
Defined Under Namespace
Classes: PrefixContribution
Instance Attribute Summary collapse
-
#top_prefixes ⇒ ::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution>
readonly
Output only.
Instance Attribute Details
#top_prefixes ⇒ ::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution> (readonly)
Returns Output only. A list of top object prefixes driving the increase in throttled requests.
1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1563 class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents throttled requests details for an object prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] throttled_requests # @return [::Integer] # Output only. The count of throttled requests for the object prefix. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in throttled requests for the # object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |