Class: Google::Cloud::Storage::Control::V2::ListIntelligenceFindingsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Request message to list IntelligenceFinding resources associated with a project.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. The filter expression to be applied. Supports filtering by type and associated_resources.

Returns:

  • (::String)

    Optional. The filter expression to be applied. Supports filtering by type and associated_resources.



1412
1413
1414
1415
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1412

class ListIntelligenceFindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. The maximum number of IntelligenceFinding resources to return.

The maximum value is 100; values above 100 will be coerced to 100. The default value is 100.

Returns:

  • (::Integer)

    Optional. The maximum number of IntelligenceFinding resources to return.

    The maximum value is 100; values above 100 will be coerced to 100. The default value is 100.



1412
1413
1414
1415
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1412

class ListIntelligenceFindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListIntelligenceFindings call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListIntelligenceFindings must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListIntelligenceFindings call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListIntelligenceFindings must match the call that provided the page token.



1412
1413
1414
1415
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1412

class ListIntelligenceFindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent of the IntelligenceFinding resource.

Format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent of the IntelligenceFinding resource.

    Format: projects/{project}/locations/{location}



1412
1413
1414
1415
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1412

class ListIntelligenceFindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end