Class: Google::Cloud::Storage::Control::V2::ListRapidCachesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Request message for ListRapidCaches.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Maximum number of caches to return in a single response. The service will use this parameter or 1,000 items, whichever is smaller.

Returns:

  • (::Integer)

    Maximum number of caches to return in a single response. The service will use this parameter or 1,000 items, whichever is smaller.



1021
1022
1023
1024
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1021

class ListRapidCachesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns A previously-returned page token representing part of the larger set of results to view.

Returns:

  • (::String)

    A previously-returned page token representing part of the larger set of results to view.



1021
1022
1023
1024
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1021

class ListRapidCachesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The bucket to which this cache belongs.

Returns:

  • (::String)

    Required. The bucket to which this cache belongs.



1021
1022
1023
1024
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1021

class ListRapidCachesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. A unique identifier for this request. UUID is the recommended format, but other formats are still accepted.

Returns:

  • (::String)

    Optional. A unique identifier for this request. UUID is the recommended format, but other formats are still accepted.



1021
1022
1023
1024
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1021

class ListRapidCachesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end