Class: Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Rapid Cache policy for a managed folder.

Defined Under Namespace

Modules: IngestOnWrite

Instance Attribute Summary collapse

Instance Attribute Details

#ingest_on_write::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy::IngestOnWrite

Returns Required. If enabled, objects in the Managed Folder will be ingested into the cache when they are written.

Returns:



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 412

class RapidCachePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The behavior of the rapid cache when an object is written.
  module IngestOnWrite
    # The behavior is not specified at this resource level.
    # It should be inherited from the parent resource's configuration.
    # This is the default value.
    INGEST_ON_WRITE_UNSPECIFIED = 0

    # Ingestion on write is explicitly enabled for this resource.
    INGEST_ON_WRITE_ENABLED = 1
  end
end

#rapid_cache_id::String

Returns Required. The identifier for the rapid cache.

Returns:

  • (::String)

    Required. The identifier for the rapid cache.



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 412

class RapidCachePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The behavior of the rapid cache when an object is written.
  module IngestOnWrite
    # The behavior is not specified at this resource level.
    # It should be inherited from the parent resource's configuration.
    # This is the default value.
    INGEST_ON_WRITE_UNSPECIFIED = 0

    # Ingestion on write is explicitly enabled for this resource.
    INGEST_ON_WRITE_ENABLED = 1
  end
end