Module: Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy::IngestOnWrite

Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

The behavior of the rapid cache when an object is written.

Constant Summary collapse

INGEST_ON_WRITE_UNSPECIFIED =

The behavior is not specified at this resource level. It should be inherited from the parent resource's configuration. This is the default value.

0
INGEST_ON_WRITE_ENABLED =

Ingestion on write is explicitly enabled for this resource.

1