Class: Google::Cloud::Storage::Control::V2::RapidCache

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

A Rapid Cache Instance.

Instance Attribute Summary collapse

Instance Attribute Details

#admission_policy::String

Returns Cache admission policy. Valid policies includes: no_read_admission, admit-on-first-miss and admit-on-second-miss. Defaults to admit-on-first-miss for both AC and RCU. Default value is applied if not specified in the create request.

Returns:

  • (::String)

    Cache admission policy. Valid policies includes: no_read_admission, admit-on-first-miss and admit-on-second-miss. Defaults to admit-on-first-miss for both AC and RCU. Default value is applied if not specified in the create request.



942
943
944
945
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 942

class RapidCache
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#cache_type::String

Returns Immutable. The type of Rapid Cache this represents. Valid values include: 'rapid-cache' and 'rapid-cache-ultra'.

Returns:

  • (::String)

    Immutable. The type of Rapid Cache this represents. Valid values include: 'rapid-cache' and 'rapid-cache-ultra'.



942
943
944
945
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 942

class RapidCache
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Time when Rapid cache instance is allocated.

Returns:



942
943
944
945
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 942

class RapidCache
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Immutable. The resource name of this RapidCache. Format: projects/{project}/buckets/{bucket}/rapidCaches/{rapid_cache}.

Returns:

  • (::String)

    Immutable. The resource name of this RapidCache. Format: projects/{project}/buckets/{bucket}/rapidCaches/{rapid_cache}



942
943
944
945
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 942

class RapidCache
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#pending_update::Boolean (readonly)

Returns Output only. True if there is an active update operation against this cache instance. Subsequential update requests will be rejected if this field is true. Output only.

Returns:

  • (::Boolean)

    Output only. True if there is an active update operation against this cache instance. Subsequential update requests will be rejected if this field is true. Output only.



942
943
944
945
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 942

class RapidCache
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#state::String (readonly)

Returns Output only. Cache state including running, creating, and disabled.

Returns:

  • (::String)

    Output only. Cache state including running, creating, and disabled.



942
943
944
945
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 942

class RapidCache
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ttl::Google::Protobuf::Duration

Returns Cache entry TTL (ranges between 1h to 7d). This is a cache-level config that defines how long a cache entry can live. Default ttl value (24hrs) is applied if not specified in the create request. TTL must be in whole seconds.

Returns:

  • (::Google::Protobuf::Duration)

    Cache entry TTL (ranges between 1h to 7d). This is a cache-level config that defines how long a cache entry can live. Default ttl value (24hrs) is applied if not specified in the create request. TTL must be in whole seconds.



942
943
944
945
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 942

class RapidCache
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Time when Rapid cache instance is last updated, including creation.

Returns:



942
943
944
945
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 942

class RapidCache
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zone::String

Returns Immutable. The zone in which the cache instance is running. For example, us-central1-a.

Returns:

  • (::String)

    Immutable. The zone in which the cache instance is running. For example, us-central1-a.



942
943
944
945
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 942

class RapidCache
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end