Class: Google::Cloud::Storage::Control::V2::StorageLayout

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

The storage layout configuration of a bucket.

Defined Under Namespace

Classes: CustomPlacementConfig, HierarchicalNamespace

Instance Attribute Summary collapse

Instance Attribute Details

#custom_placement_config::Google::Cloud::Storage::Control::V2::StorageLayout::CustomPlacementConfig (readonly)

Returns Output only. The data placement configuration for custom dual region. If there is no configuration, this is not a custom dual region bucket.

Returns:



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 323

class StorageLayout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for Custom Dual Regions.  It should specify precisely two
  # eligible regions within the same Multiregion. More information on regions
  # may be found [here](https://cloud.google.com/storage/docs/locations).
  # @!attribute [rw] data_locations
  #   @return [::Array<::String>]
  #     List of locations to use for data placement.
  class CustomPlacementConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for a bucket's hierarchical namespace feature.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Enables the hierarchical namespace feature.
  class HierarchicalNamespace
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#hierarchical_namespace::Google::Cloud::Storage::Control::V2::StorageLayout::HierarchicalNamespace (readonly)

Returns Output only. The bucket's hierarchical namespace configuration. If there is no configuration, the hierarchical namespace is disabled.

Returns:



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 323

class StorageLayout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for Custom Dual Regions.  It should specify precisely two
  # eligible regions within the same Multiregion. More information on regions
  # may be found [here](https://cloud.google.com/storage/docs/locations).
  # @!attribute [rw] data_locations
  #   @return [::Array<::String>]
  #     List of locations to use for data placement.
  class CustomPlacementConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for a bucket's hierarchical namespace feature.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Enables the hierarchical namespace feature.
  class HierarchicalNamespace
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#location::String (readonly)

Returns Output only. The location of the bucket.

Returns:

  • (::String)

    Output only. The location of the bucket.



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 323

class StorageLayout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for Custom Dual Regions.  It should specify precisely two
  # eligible regions within the same Multiregion. More information on regions
  # may be found [here](https://cloud.google.com/storage/docs/locations).
  # @!attribute [rw] data_locations
  #   @return [::Array<::String>]
  #     List of locations to use for data placement.
  class CustomPlacementConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for a bucket's hierarchical namespace feature.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Enables the hierarchical namespace feature.
  class HierarchicalNamespace
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#location_type::String (readonly)

Returns Output only. The location type of the bucket (region, dual-region, multi-region, etc).

Returns:

  • (::String)

    Output only. The location type of the bucket (region, dual-region, multi-region, etc).



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 323

class StorageLayout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for Custom Dual Regions.  It should specify precisely two
  # eligible regions within the same Multiregion. More information on regions
  # may be found [here](https://cloud.google.com/storage/docs/locations).
  # @!attribute [rw] data_locations
  #   @return [::Array<::String>]
  #     List of locations to use for data placement.
  class CustomPlacementConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for a bucket's hierarchical namespace feature.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Enables the hierarchical namespace feature.
  class HierarchicalNamespace
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String (readonly)

Returns Output only. The name of the StorageLayout resource. Format: projects/{project}/buckets/{bucket}/storageLayout.

Returns:

  • (::String)

    Output only. The name of the StorageLayout resource. Format: projects/{project}/buckets/{bucket}/storageLayout



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 323

class StorageLayout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for Custom Dual Regions.  It should specify precisely two
  # eligible regions within the same Multiregion. More information on regions
  # may be found [here](https://cloud.google.com/storage/docs/locations).
  # @!attribute [rw] data_locations
  #   @return [::Array<::String>]
  #     List of locations to use for data placement.
  class CustomPlacementConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for a bucket's hierarchical namespace feature.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Enables the hierarchical namespace feature.
  class HierarchicalNamespace
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end