Class: Google::Cloud::Storage::Control::V2::StorageLayout::CustomPlacementConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Configuration for Custom Dual Regions. It should specify precisely two eligible regions within the same Multiregion. More information on regions may be found here.

Instance Attribute Summary collapse

Instance Attribute Details

#data_locations::Array<::String>

Returns List of locations to use for data placement.

Returns:

  • (::Array<::String>)

    List of locations to use for data placement.



333
334
335
336
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 333

class CustomPlacementConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end