Module: Google::Cloud::Storage::Control::V2::SummarizeIntelligenceFindingsRequest::ResourceScope

Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

The list of resource scopes.

Constant Summary collapse

RESOURCE_SCOPE_UNSPECIFIED =

The default behavior. Falls back to PARENT behaviour

0
PARENT =

Summaries are aggregated at the level of the parent resource.

1
PROJECT =

Summaries are broken down by each project within the parent scope.

2