Class: Google::Cloud::Storage::Control::V2::SummarizeIntelligenceFindingsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Response message to summarize the intelligence findings for a specified scope(org, folder or project).

Instance Attribute Summary collapse

Instance Attribute Details

#finding_summaries::Array<::Google::Cloud::Storage::Control::V2::FindingSummary>

Returns The list of FindingSummary summaries.

Returns:



1499
1500
1501
1502
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1499

class SummarizeIntelligenceFindingsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to SummarizeIntelligenceFindings to retrieve the next page of results.

Returns:

  • (::String)

    A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to SummarizeIntelligenceFindings to retrieve the next page of results.



1499
1500
1501
1502
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1499

class SummarizeIntelligenceFindingsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end