Class: Google::Cloud::Storage::Control::V2::UpdateAnywhereCacheMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Message returned in the metadata field of the Operation resource for UpdateAnywhereCache operation.

Instance Attribute Summary collapse

Instance Attribute Details

#admission_policy::String

Returns Optional. Anywhere Cache entry Admission Policy in kebab-case (e.g., "admit-on-first-miss"). If admission_policy is pending update, this field equals to the new value specified in the Update request.

Returns:

  • (::String)

    Optional. Anywhere Cache entry Admission Policy in kebab-case (e.g., "admit-on-first-miss"). If admission_policy is pending update, this field equals to the new value specified in the Update request.



676
677
678
679
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 676

class UpdateAnywhereCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#anywhere_cache_id::String

Returns Anywhere Cache ID.

Returns:

  • (::String)

    Anywhere Cache ID.



676
677
678
679
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 676

class UpdateAnywhereCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#common_metadata::Google::Cloud::Storage::Control::V2::CommonLongRunningOperationMetadata

Returns Generic metadata for the long running operation.

Returns:



676
677
678
679
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 676

class UpdateAnywhereCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ingest_on_write::Boolean

Returns Specifies whether objects are ingested into the cache upon write. If not set, it defaults to false.

Returns:

  • (::Boolean)

    Specifies whether objects are ingested into the cache upon write. If not set, it defaults to false.



676
677
678
679
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 676

class UpdateAnywhereCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ttl::Google::Protobuf::Duration

Returns Anywhere Cache entry's TTL between 1h and 7days. A cache-level config that is applied to all new cache entries on admission. If ttl is pending update, this field equals to the new value specified in the Update request.

Returns:

  • (::Google::Protobuf::Duration)

    Anywhere Cache entry's TTL between 1h and 7days. A cache-level config that is applied to all new cache entries on admission. If ttl is pending update, this field equals to the new value specified in the Update request.



676
677
678
679
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 676

class UpdateAnywhereCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zone::String

Returns The zone in which the cache instance is running. For example, us-central1-a.

Returns:

  • (::String)

    The zone in which the cache instance is running. For example, us-central1-a.



676
677
678
679
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 676

class UpdateAnywhereCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end