Class: Google::Cloud::Storage::Control::V2::UpdateManagedFolderRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Request message for UpdateManagedFolder.

Instance Attribute Summary collapse

Instance Attribute Details

#if_metageneration_match::Integer

Returns Optional. The operation succeeds conditional on the managed folder's current metageneration matching the value here specified.

Returns:

  • (::Integer)

    Optional. The operation succeeds conditional on the managed folder's current metageneration matching the value here specified.



580
581
582
583
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 580

class UpdateManagedFolderRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#if_metageneration_not_match::Integer

Returns Optional. The operation succeeds conditional on the managed folder's current metageneration NOT matching the value here specified.

Returns:

  • (::Integer)

    Optional. The operation succeeds conditional on the managed folder's current metageneration NOT matching the value here specified.



580
581
582
583
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 580

class UpdateManagedFolderRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#managed_folder::Google::Cloud::Storage::Control::V2::ManagedFolder

Returns Required. Properties of the managed folder being updated. Currently, this RPC only supports updating the rapid_cache_config field in managed_folder.

Returns:



580
581
582
583
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 580

class UpdateManagedFolderRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. A unique identifier for this request. UUID is the recommended format, but other formats are still accepted.

Returns:

  • (::String)

    Optional. A unique identifier for this request. UUID is the recommended format, but other formats are still accepted.



580
581
582
583
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 580

class UpdateManagedFolderRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. Update mask for managed_folder. Currently, this RPC only supports updating the rapid_cache_config field in managed_folder. This field also supports update mask for the subfields in the map of rapid_cache_config. The user can specify the update mask for rapid_cache_config.policies and rapid_cache_config.policies.<key>, but patching is not supported for a field within RapidCachePolicy.policies.<key>, like rapid_cache_config.policies.[key].ingest_on_write.

Returns:

  • (::Google::Protobuf::FieldMask)

    Optional. Update mask for managed_folder. Currently, this RPC only supports updating the rapid_cache_config field in managed_folder. This field also supports update mask for the subfields in the map of rapid_cache_config. The user can specify the update mask for rapid_cache_config.policies and rapid_cache_config.policies.<key>, but patching is not supported for a field within RapidCachePolicy.policies.<key>, like rapid_cache_config.policies.[key].ingest_on_write.



580
581
582
583
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 580

class UpdateManagedFolderRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end