Class: Google::Cloud::Storage::Control::V2::UpdateRapidCacheMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Message returned in the metadata field of the Operation resource for UpdateRapidCache operation.

Instance Attribute Summary collapse

Instance Attribute Details

#admission_policy::String

Returns Optional. Rapid Cache entry Admission Policy in kebab-case (e.g., "admit-on-first-miss"). If admission_policy is pending update, this field equals to the new value specified in the Update request.

Returns:

  • (::String)

    Optional. Rapid Cache entry Admission Policy in kebab-case (e.g., "admit-on-first-miss"). If admission_policy is pending update, this field equals to the new value specified in the Update request.



710
711
712
713
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 710

class UpdateRapidCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#cache_type::String

Returns Optional. The type of cache. Either rapid cache or rapid cache ultra.

Returns:

  • (::String)

    Optional. The type of cache. Either rapid cache or rapid cache ultra.



710
711
712
713
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 710

class UpdateRapidCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#common_metadata::Google::Cloud::Storage::Control::V2::CommonLongRunningOperationMetadata

Returns Generic metadata for the long running operation.

Returns:



710
711
712
713
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 710

class UpdateRapidCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ingest_on_write::Boolean

Returns Specifies whether objects are ingested into the cache upon write. If not set, it defaults to false.

Returns:

  • (::Boolean)

    Specifies whether objects are ingested into the cache upon write. If not set, it defaults to false.



710
711
712
713
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 710

class UpdateRapidCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rapid_cache_id::String

Returns Rapid Cache ID.

Returns:

  • (::String)

    Rapid Cache ID.



710
711
712
713
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 710

class UpdateRapidCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ttl::Google::Protobuf::Duration

Returns Rapid Cache entry's TTL between 1h and 7days. A cache-level config that is applied to all new cache entries on admission. If ttl is pending update, this field equals to the new value specified in the Update request.

Returns:

  • (::Google::Protobuf::Duration)

    Rapid Cache entry's TTL between 1h and 7days. A cache-level config that is applied to all new cache entries on admission. If ttl is pending update, this field equals to the new value specified in the Update request.



710
711
712
713
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 710

class UpdateRapidCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zone::String

Returns The zone in which the cache instance is running. For example, us-central1-a.

Returns:

  • (::String)

    The zone in which the cache instance is running. For example, us-central1-a.



710
711
712
713
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 710

class UpdateRapidCacheMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end