Class: Google::Cloud::Storage::Control::V2::UpdateRapidCacheRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Request message for UpdateRapidCache.

Instance Attribute Summary collapse

Instance Attribute Details

#rapid_cache::Google::Cloud::Storage::Control::V2::RapidCache

Returns Required. The RapidCache to update.

Returns:



986
987
988
989
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 986

class UpdateRapidCacheRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. A unique identifier for this request. UUID is the recommended format, but other formats are still accepted. This request is only idempotent if a request_id is provided.

Returns:

  • (::String)

    Optional. A unique identifier for this request. UUID is the recommended format, but other formats are still accepted. This request is only idempotent if a request_id is provided.



986
987
988
989
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 986

class UpdateRapidCacheRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Required. List of fields to be updated. Mutable fields of RapidCache include ttl, admission_policy and ingest_on_write.

To specify ALL fields, specify a single field with the value *. Note: We recommend against doing this. If a new field is introduced at a later time, an older client updating with the * may accidentally reset the new field's value.

Not specifying any fields is an error.

Returns:

  • (::Google::Protobuf::FieldMask)

    Required. List of fields to be updated. Mutable fields of RapidCache include ttl, admission_policy and ingest_on_write.

    To specify ALL fields, specify a single field with the value *. Note: We recommend against doing this. If a new field is introduced at a later time, an older client updating with the * may accidentally reset the new field's value.

    Not specifying any fields is an error.



986
987
988
989
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 986

class UpdateRapidCacheRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end