Class: Google::Cloud::Storage::Control::V2::AnywhereCache
- Inherits:
-
Object
- Object
- Google::Cloud::Storage::Control::V2::AnywhereCache
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/storage/control/v2/storage_control.rb
Overview
An Anywhere Cache Instance.
Instance Attribute Summary collapse
-
#admission_policy ⇒ ::String
Cache admission policy.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#name ⇒ ::String
Immutable.
-
#pending_update ⇒ ::Boolean
readonly
Output only.
-
#state ⇒ ::String
readonly
Output only.
-
#ttl ⇒ ::Google::Protobuf::Duration
Cache entry TTL (ranges between 1h to 7d).
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#zone ⇒ ::String
Immutable.
Instance Attribute Details
#admission_policy ⇒ ::String
Returns Cache admission policy. Valid policies includes:
admit-on-first-miss and admit-on-second-miss. Defaults to
admit-on-first-miss. Default value is applied if not specified in the
create request.
592 593 594 595 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 592 class AnywhereCache include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Time when Anywhere cache instance is allocated.
592 593 594 595 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 592 class AnywhereCache include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Immutable. The resource name of this AnywhereCache.
Format:
projects/{project}/buckets/{bucket}/anywhereCaches/{anywhere_cache}.
592 593 594 595 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 592 class AnywhereCache include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pending_update ⇒ ::Boolean (readonly)
Returns Output only. True if there is an active update operation against this cache instance. Subsequential update requests will be rejected if this field is true. Output only.
592 593 594 595 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 592 class AnywhereCache include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#state ⇒ ::String (readonly)
Returns Output only. Cache state including RUNNING, CREATING, DISABLED and PAUSED.
592 593 594 595 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 592 class AnywhereCache include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ttl ⇒ ::Google::Protobuf::Duration
Returns Cache entry TTL (ranges between 1h to 7d). This is a cache-level config that defines how long a cache entry can live. Default ttl value (24hrs) is applied if not specified in the create request. TTL must be in whole seconds.
592 593 594 595 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 592 class AnywhereCache include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Time when Anywhere cache instance is last updated, including creation.
592 593 594 595 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 592 class AnywhereCache include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#zone ⇒ ::String
Returns Immutable. The zone in which the cache instance is running. For example, us-central1-a.
592 593 594 595 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 592 class AnywhereCache include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |