Class: Google::Cloud::Storage::Control::V2::FindingSummary

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

A summary of findings generated for an organization, a folder, or a project.

Defined Under Namespace

Classes: SummaryDetails

Instance Attribute Summary collapse

Instance Attribute Details

#category::Google::Cloud::Storage::Control::V2::FindingCategory (readonly)

Returns Output only. The category of finding.

Returns:



1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1581

class FindingSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Details about the `FindingSummary` resource.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The count of impacted resources.
  #
  #     Note: The following fields are mutually exclusive: `count`, `percentage`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] percentage
  #   @return [::Float]
  #     The percentage of impacted resources.
  #
  #     Note: The following fields are mutually exclusive: `percentage`, `count`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] resource_type
  #   @return [::Google::Cloud::Storage::Control::V2::FindingSummary::SummaryDetails::ResourceType]
  #     Output only. The type of Cloud resource this summary detail applies to.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A short description about the FindingSummary
  class SummaryDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The list of resource types.
    module ResourceType
      # Resource type is unspecified.
      RESOURCE_TYPE_UNSPECIFIED = 0

      # Resource type is project.
      PROJECT = 1

      # Resource type is bucket.
      BUCKET = 2
    end
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The creation time of the earliest finding that this summary is based on.

Returns:



1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1581

class FindingSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Details about the `FindingSummary` resource.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The count of impacted resources.
  #
  #     Note: The following fields are mutually exclusive: `count`, `percentage`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] percentage
  #   @return [::Float]
  #     The percentage of impacted resources.
  #
  #     Note: The following fields are mutually exclusive: `percentage`, `count`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] resource_type
  #   @return [::Google::Cloud::Storage::Control::V2::FindingSummary::SummaryDetails::ResourceType]
  #     Output only. The type of Cloud resource this summary detail applies to.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A short description about the FindingSummary
  class SummaryDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The list of resource types.
    module ResourceType
      # Resource type is unspecified.
      RESOURCE_TYPE_UNSPECIFIED = 0

      # Resource type is project.
      PROJECT = 1

      # Resource type is bucket.
      BUCKET = 2
    end
  end
end

#severity::Google::Cloud::Storage::Control::V2::FindingSeverity (readonly)

Returns Severity of the finding.

Returns:



1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1581

class FindingSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Details about the `FindingSummary` resource.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The count of impacted resources.
  #
  #     Note: The following fields are mutually exclusive: `count`, `percentage`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] percentage
  #   @return [::Float]
  #     The percentage of impacted resources.
  #
  #     Note: The following fields are mutually exclusive: `percentage`, `count`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] resource_type
  #   @return [::Google::Cloud::Storage::Control::V2::FindingSummary::SummaryDetails::ResourceType]
  #     Output only. The type of Cloud resource this summary detail applies to.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A short description about the FindingSummary
  class SummaryDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The list of resource types.
    module ResourceType
      # Resource type is unspecified.
      RESOURCE_TYPE_UNSPECIFIED = 0

      # Resource type is project.
      PROJECT = 1

      # Resource type is bucket.
      BUCKET = 2
    end
  end
end

#summary_details::Array<::Google::Cloud::Storage::Control::V2::FindingSummary::SummaryDetails> (readonly)

Returns Output only. List of SummaryDetails.

Returns:



1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1581

class FindingSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Details about the `FindingSummary` resource.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The count of impacted resources.
  #
  #     Note: The following fields are mutually exclusive: `count`, `percentage`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] percentage
  #   @return [::Float]
  #     The percentage of impacted resources.
  #
  #     Note: The following fields are mutually exclusive: `percentage`, `count`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] resource_type
  #   @return [::Google::Cloud::Storage::Control::V2::FindingSummary::SummaryDetails::ResourceType]
  #     Output only. The type of Cloud resource this summary detail applies to.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A short description about the FindingSummary
  class SummaryDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The list of resource types.
    module ResourceType
      # Resource type is unspecified.
      RESOURCE_TYPE_UNSPECIFIED = 0

      # Resource type is project.
      PROJECT = 1

      # Resource type is bucket.
      BUCKET = 2
    end
  end
end

#target_resource::String (readonly)

Returns Output only. The fully qualified Cloud resource name for which this summary was generated. eg: //cloudresourcemanager.googleapis.com/projects/p1.

Returns:

  • (::String)

    Output only. The fully qualified Cloud resource name for which this summary was generated. eg: //cloudresourcemanager.googleapis.com/projects/p1



1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1581

class FindingSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Details about the `FindingSummary` resource.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The count of impacted resources.
  #
  #     Note: The following fields are mutually exclusive: `count`, `percentage`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] percentage
  #   @return [::Float]
  #     The percentage of impacted resources.
  #
  #     Note: The following fields are mutually exclusive: `percentage`, `count`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] resource_type
  #   @return [::Google::Cloud::Storage::Control::V2::FindingSummary::SummaryDetails::ResourceType]
  #     Output only. The type of Cloud resource this summary detail applies to.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A short description about the FindingSummary
  class SummaryDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The list of resource types.
    module ResourceType
      # Resource type is unspecified.
      RESOURCE_TYPE_UNSPECIFIED = 0

      # Resource type is project.
      PROJECT = 1

      # Resource type is bucket.
      BUCKET = 2
    end
  end
end

#type::Google::Cloud::Storage::Control::V2::FindingType (readonly)

Returns Output only. The type of the finding.

Returns:



1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1581

class FindingSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Details about the `FindingSummary` resource.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The count of impacted resources.
  #
  #     Note: The following fields are mutually exclusive: `count`, `percentage`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] percentage
  #   @return [::Float]
  #     The percentage of impacted resources.
  #
  #     Note: The following fields are mutually exclusive: `percentage`, `count`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] resource_type
  #   @return [::Google::Cloud::Storage::Control::V2::FindingSummary::SummaryDetails::ResourceType]
  #     Output only. The type of Cloud resource this summary detail applies to.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A short description about the FindingSummary
  class SummaryDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The list of resource types.
    module ResourceType
      # Resource type is unspecified.
      RESOURCE_TYPE_UNSPECIFIED = 0

      # Resource type is project.
      PROJECT = 1

      # Resource type is bucket.
      BUCKET = 2
    end
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time of the most recent update among all the findings that this summary is based on.

Returns:



1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1581

class FindingSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Details about the `FindingSummary` resource.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The count of impacted resources.
  #
  #     Note: The following fields are mutually exclusive: `count`, `percentage`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] percentage
  #   @return [::Float]
  #     The percentage of impacted resources.
  #
  #     Note: The following fields are mutually exclusive: `percentage`, `count`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] resource_type
  #   @return [::Google::Cloud::Storage::Control::V2::FindingSummary::SummaryDetails::ResourceType]
  #     Output only. The type of Cloud resource this summary detail applies to.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A short description about the FindingSummary
  class SummaryDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The list of resource types.
    module ResourceType
      # Resource type is unspecified.
      RESOURCE_TYPE_UNSPECIFIED = 0

      # Resource type is project.
      PROJECT = 1

      # Resource type is bucket.
      BUCKET = 2
    end
  end
end