Class: Google::Cloud::Storage::Control::V2::FindingSummary::SummaryDetails
- Inherits:
-
Object
- Object
- Google::Cloud::Storage::Control::V2::FindingSummary::SummaryDetails
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/storage/control/v2/storage_control.rb
Overview
Details about the FindingSummary resource.
Defined Under Namespace
Modules: ResourceType
Instance Attribute Summary collapse
-
#count ⇒ ::Integer
The count of impacted resources.
-
#description ⇒ ::String
readonly
Output only.
-
#percentage ⇒ ::Float
The percentage of impacted resources.
-
#resource_type ⇒ ::Google::Cloud::Storage::Control::V2::FindingSummary::SummaryDetails::ResourceType
readonly
Output only.
Instance Attribute Details
#count ⇒ ::Integer
Returns The count of impacted resources.
Note: The following fields are mutually exclusive: count, percentage. If a field in that set is populated, all other fields in the set will automatically be cleared.
1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1872 class SummaryDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The list of resource types. module ResourceType # Resource type is unspecified. RESOURCE_TYPE_UNSPECIFIED = 0 # Resource type is project. PROJECT = 1 # Resource type is bucket. BUCKET = 2 end end |
#description ⇒ ::String (readonly)
Returns Output only. A short description about the FindingSummary.
1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1872 class SummaryDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The list of resource types. module ResourceType # Resource type is unspecified. RESOURCE_TYPE_UNSPECIFIED = 0 # Resource type is project. PROJECT = 1 # Resource type is bucket. BUCKET = 2 end end |
#percentage ⇒ ::Float
Returns The percentage of impacted resources.
Note: The following fields are mutually exclusive: percentage, count. If a field in that set is populated, all other fields in the set will automatically be cleared.
1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1872 class SummaryDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The list of resource types. module ResourceType # Resource type is unspecified. RESOURCE_TYPE_UNSPECIFIED = 0 # Resource type is project. PROJECT = 1 # Resource type is bucket. BUCKET = 2 end end |
#resource_type ⇒ ::Google::Cloud::Storage::Control::V2::FindingSummary::SummaryDetails::ResourceType (readonly)
Returns Output only. The type of Cloud resource this summary detail applies to.
1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1872 class SummaryDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The list of resource types. module ResourceType # Resource type is unspecified. RESOURCE_TYPE_UNSPECIFIED = 0 # Resource type is project. PROJECT = 1 # Resource type is bucket. BUCKET = 2 end end |