Class: Google::Cloud::Storage::Control::V2::FindingSummary::SummaryDetails

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Details about the FindingSummary resource.

Defined Under Namespace

Modules: ResourceType

Instance Attribute Summary collapse

Instance Attribute Details

#count::Integer

Returns The count of impacted resources.

Note: The following fields are mutually exclusive: count, percentage. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Integer)

    The count of impacted resources.

    Note: The following fields are mutually exclusive: count, percentage. If a field in that set is populated, all other fields in the set will automatically be cleared.



1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1602

class SummaryDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The list of resource types.
  module ResourceType
    # Resource type is unspecified.
    RESOURCE_TYPE_UNSPECIFIED = 0

    # Resource type is project.
    PROJECT = 1

    # Resource type is bucket.
    BUCKET = 2
  end
end

#description::String (readonly)

Returns Output only. A short description about the FindingSummary.

Returns:

  • (::String)

    Output only. A short description about the FindingSummary



1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1602

class SummaryDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The list of resource types.
  module ResourceType
    # Resource type is unspecified.
    RESOURCE_TYPE_UNSPECIFIED = 0

    # Resource type is project.
    PROJECT = 1

    # Resource type is bucket.
    BUCKET = 2
  end
end

#percentage::Float

Returns The percentage of impacted resources.

Note: The following fields are mutually exclusive: percentage, count. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Float)

    The percentage of impacted resources.

    Note: The following fields are mutually exclusive: percentage, count. If a field in that set is populated, all other fields in the set will automatically be cleared.



1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1602

class SummaryDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The list of resource types.
  module ResourceType
    # Resource type is unspecified.
    RESOURCE_TYPE_UNSPECIFIED = 0

    # Resource type is project.
    PROJECT = 1

    # Resource type is bucket.
    BUCKET = 2
  end
end

#resource_type::Google::Cloud::Storage::Control::V2::FindingSummary::SummaryDetails::ResourceType (readonly)

Returns Output only. The type of Cloud resource this summary detail applies to.

Returns:



1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1602

class SummaryDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The list of resource types.
  module ResourceType
    # Resource type is unspecified.
    RESOURCE_TYPE_UNSPECIFIED = 0

    # Resource type is project.
    PROJECT = 1

    # Resource type is bucket.
    BUCKET = 2
  end
end