Class: Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike
- Inherits:
-
Object
- Object
- Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/storage/control/v2/storage_control.rb
Overview
Represents a finding about a spike in Class A/B operations on Coldline
or Archive Cloud Storage objects.
This corresponds to the COLD_AND_ARCHIVAL_STORAGE_OPERATIONS_SPIKE
finding type.
Defined Under Namespace
Classes: BucketContribution
Instance Attribute Summary collapse
-
#percentage_increase ⇒ ::Float
readonly
Output only.
-
#top_buckets ⇒ ::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution>
readonly
Output only.
-
#total_operations_count ⇒ ::Integer
readonly
Output only.
Instance Attribute Details
#percentage_increase ⇒ ::Float (readonly)
Returns Output only. The percentage increase in operations across the project.
1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1106 class ColdlineAndArchivalStorageOperationsSpike include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the operation spike details for a bucket. # @!attribute [r] bucket # @return [::String] # Output only. The name of the bucket. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in operations for the bucket. # @!attribute [r] total_operations_count # @return [::Integer] # Output only. The total count of operations for the bucket. # @!attribute [r] contribution # @return [::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution] # Output only. The details about the contribution of the bucket. # # Note: The following fields are mutually exclusive: `contribution`, `error`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] error # @return [::Google::Rpc::Status] # Output only. The error related to accessing the details about the # contribution of the bucket. # # Note: The following fields are mutually exclusive: `error`, `contribution`. If a field in that set is populated, all other fields in the set will automatically be cleared. class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the contribution of the bucket towards the # `IntelligenceFinding`. # @!attribute [r] top_prefixes # @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution::PrefixContribution>] # Output only. A list of the top object prefixes driving the increase # in operations. class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the operation spike details for an object prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in operations for the object # prefix. # @!attribute [r] total_operations_count # @return [::Integer] # Output only. The total count of operations for the object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |
#top_buckets ⇒ ::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution> (readonly)
Returns Output only. A list of the top buckets driving the increase in operations.
1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1106 class ColdlineAndArchivalStorageOperationsSpike include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the operation spike details for a bucket. # @!attribute [r] bucket # @return [::String] # Output only. The name of the bucket. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in operations for the bucket. # @!attribute [r] total_operations_count # @return [::Integer] # Output only. The total count of operations for the bucket. # @!attribute [r] contribution # @return [::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution] # Output only. The details about the contribution of the bucket. # # Note: The following fields are mutually exclusive: `contribution`, `error`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] error # @return [::Google::Rpc::Status] # Output only. The error related to accessing the details about the # contribution of the bucket. # # Note: The following fields are mutually exclusive: `error`, `contribution`. If a field in that set is populated, all other fields in the set will automatically be cleared. class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the contribution of the bucket towards the # `IntelligenceFinding`. # @!attribute [r] top_prefixes # @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution::PrefixContribution>] # Output only. A list of the top object prefixes driving the increase # in operations. class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the operation spike details for an object prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in operations for the object # prefix. # @!attribute [r] total_operations_count # @return [::Integer] # Output only. The total count of operations for the object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |
#total_operations_count ⇒ ::Integer (readonly)
Returns Output only. The total count of operations across the project.
1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1106 class ColdlineAndArchivalStorageOperationsSpike include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the operation spike details for a bucket. # @!attribute [r] bucket # @return [::String] # Output only. The name of the bucket. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in operations for the bucket. # @!attribute [r] total_operations_count # @return [::Integer] # Output only. The total count of operations for the bucket. # @!attribute [r] contribution # @return [::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution] # Output only. The details about the contribution of the bucket. # # Note: The following fields are mutually exclusive: `contribution`, `error`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] error # @return [::Google::Rpc::Status] # Output only. The error related to accessing the details about the # contribution of the bucket. # # Note: The following fields are mutually exclusive: `error`, `contribution`. If a field in that set is populated, all other fields in the set will automatically be cleared. class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the contribution of the bucket towards the # `IntelligenceFinding`. # @!attribute [r] top_prefixes # @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution::PrefixContribution>] # Output only. A list of the top object prefixes driving the increase # in operations. class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the operation spike details for an object prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in operations for the object # prefix. # @!attribute [r] total_operations_count # @return [::Integer] # Output only. The total count of operations for the object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |