Class: Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution
- Inherits:
-
Object
- Object
- Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/storage/control/v2/storage_control.rb
Overview
Represents the operation spike details for a bucket.
Defined Under Namespace
Classes: Contribution
Instance Attribute Summary collapse
-
#bucket ⇒ ::String
readonly
Output only.
-
#contribution ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution
readonly
Output only.
-
#error ⇒ ::Google::Rpc::Status
readonly
Output only.
-
#percentage_increase ⇒ ::Float
readonly
Output only.
-
#total_operations_count ⇒ ::Integer
readonly
Output only.
Instance Attribute Details
#bucket ⇒ ::String (readonly)
Returns Output only. The name of the bucket.
1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1401 class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the contribution of the bucket towards the # `IntelligenceFinding`. # @!attribute [r] top_prefixes # @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution::PrefixContribution>] # Output only. A list of the top object prefixes driving the increase # in operations. class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the operation spike details for an object prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in operations for the object # prefix. # @!attribute [r] total_operations_count # @return [::Integer] # Output only. The total count of operations for the object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#contribution ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution (readonly)
Returns Output only. The details about the contribution of the bucket.
Note: The following fields are mutually exclusive: contribution, error. If a field in that set is populated, all other fields in the set will automatically be cleared.
1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1401 class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the contribution of the bucket towards the # `IntelligenceFinding`. # @!attribute [r] top_prefixes # @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution::PrefixContribution>] # Output only. A list of the top object prefixes driving the increase # in operations. class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the operation spike details for an object prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in operations for the object # prefix. # @!attribute [r] total_operations_count # @return [::Integer] # Output only. The total count of operations for the object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#error ⇒ ::Google::Rpc::Status (readonly)
Returns Output only. The error related to accessing the details about the contribution of the bucket.
Note: The following fields are mutually exclusive: error, contribution. If a field in that set is populated, all other fields in the set will automatically be cleared.
1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1401 class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the contribution of the bucket towards the # `IntelligenceFinding`. # @!attribute [r] top_prefixes # @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution::PrefixContribution>] # Output only. A list of the top object prefixes driving the increase # in operations. class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the operation spike details for an object prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in operations for the object # prefix. # @!attribute [r] total_operations_count # @return [::Integer] # Output only. The total count of operations for the object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#percentage_increase ⇒ ::Float (readonly)
Returns Output only. The percentage increase in operations for the bucket.
1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1401 class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the contribution of the bucket towards the # `IntelligenceFinding`. # @!attribute [r] top_prefixes # @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution::PrefixContribution>] # Output only. A list of the top object prefixes driving the increase # in operations. class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the operation spike details for an object prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in operations for the object # prefix. # @!attribute [r] total_operations_count # @return [::Integer] # Output only. The total count of operations for the object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#total_operations_count ⇒ ::Integer (readonly)
Returns Output only. The total count of operations for the bucket.
1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1401 class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the contribution of the bucket towards the # `IntelligenceFinding`. # @!attribute [r] top_prefixes # @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution::PrefixContribution>] # Output only. A list of the top object prefixes driving the increase # in operations. class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the operation spike details for an object prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in operations for the object # prefix. # @!attribute [r] total_operations_count # @return [::Integer] # Output only. The total count of operations for the object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |