Class: Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Represents the operation spike details for a bucket.

Defined Under Namespace

Classes: Contribution

Instance Attribute Summary collapse

Instance Attribute Details

#bucket::String (readonly)

Returns Output only. The name of the bucket.

Returns:

  • (::String)

    Output only. The name of the bucket.



1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1131

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of the top object prefixes driving the increase
  #     in operations.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the operation spike details for an object prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in operations for the object
    #     prefix.
    # @!attribute [r] total_operations_count
    #   @return [::Integer]
    #     Output only. The total count of operations for the object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#contribution::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution (readonly)

Returns Output only. The details about the contribution of the bucket.

Note: The following fields are mutually exclusive: contribution, error. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1131

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of the top object prefixes driving the increase
  #     in operations.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the operation spike details for an object prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in operations for the object
    #     prefix.
    # @!attribute [r] total_operations_count
    #   @return [::Integer]
    #     Output only. The total count of operations for the object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#error::Google::Rpc::Status (readonly)

Returns Output only. The error related to accessing the details about the contribution of the bucket.

Note: The following fields are mutually exclusive: error, contribution. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Rpc::Status)

    Output only. The error related to accessing the details about the contribution of the bucket.

    Note: The following fields are mutually exclusive: error, contribution. If a field in that set is populated, all other fields in the set will automatically be cleared.



1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1131

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of the top object prefixes driving the increase
  #     in operations.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the operation spike details for an object prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in operations for the object
    #     prefix.
    # @!attribute [r] total_operations_count
    #   @return [::Integer]
    #     Output only. The total count of operations for the object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#percentage_increase::Float (readonly)

Returns Output only. The percentage increase in operations for the bucket.

Returns:

  • (::Float)

    Output only. The percentage increase in operations for the bucket.



1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1131

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of the top object prefixes driving the increase
  #     in operations.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the operation spike details for an object prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in operations for the object
    #     prefix.
    # @!attribute [r] total_operations_count
    #   @return [::Integer]
    #     Output only. The total count of operations for the object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#total_operations_count::Integer (readonly)

Returns Output only. The total count of operations for the bucket.

Returns:

  • (::Integer)

    Output only. The total count of operations for the bucket.



1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1131

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ColdlineAndArchivalStorageOperationsSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of the top object prefixes driving the increase
  #     in operations.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the operation spike details for an object prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in operations for the object
    #     prefix.
    # @!attribute [r] total_operations_count
    #   @return [::Integer]
    #     Output only. The total count of operations for the object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end