Class: Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike
- Inherits:
-
Object
- Object
- Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/storage/control/v2/storage_control.rb
Overview
Represents a finding about a spike in cross-region egress from Cloud
Storage.
This corresponds to the CROSS_REGION_EGRESS_SPIKE finding type.
Defined Under Namespace
Classes: BucketContribution
Instance Attribute Summary collapse
-
#percentage_increase ⇒ ::Float
readonly
Output only.
-
#top_buckets ⇒ ::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution>
readonly
Output only.
-
#total_egress_bytes ⇒ ::Integer
readonly
Output only.
Instance Attribute Details
#percentage_increase ⇒ ::Float (readonly)
Returns Output only. The percentage increase in cross-region egress across the project.
1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1450 class CrossRegionEgressSpike include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the cross-region egress spike details for a bucket. # @!attribute [r] bucket # @return [::String] # Output only. The name of the bucket. # @!attribute [r] total_egress_bytes # @return [::Integer] # Output only. The total cross-region egress volume in bytes for the # bucket. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in cross-region egress for the # bucket. # @!attribute [r] contribution # @return [::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution] # Output only. The details about the contribution of the bucket. # # Note: The following fields are mutually exclusive: `contribution`, `error`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] error # @return [::Google::Rpc::Status] # Output only. The error related to accessing the details about the # contribution of the bucket. # # Note: The following fields are mutually exclusive: `error`, `contribution`. If a field in that set is populated, all other fields in the set will automatically be cleared. class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the contribution of the bucket towards the # `IntelligenceFinding`. # @!attribute [r] top_prefixes # @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution::PrefixContribution>] # Output only. A list of the top object prefixes driving the increase # in cross-region egress. class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the cross-region egress spike details for an object # prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] total_egress_bytes # @return [::Integer] # Output only. The total cross-region egress volume in bytes from the # object prefix. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in cross-region egress for the # object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |
#top_buckets ⇒ ::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution> (readonly)
Returns Output only. A list of top buckets driving the increase in cross-region egress.
1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1450 class CrossRegionEgressSpike include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the cross-region egress spike details for a bucket. # @!attribute [r] bucket # @return [::String] # Output only. The name of the bucket. # @!attribute [r] total_egress_bytes # @return [::Integer] # Output only. The total cross-region egress volume in bytes for the # bucket. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in cross-region egress for the # bucket. # @!attribute [r] contribution # @return [::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution] # Output only. The details about the contribution of the bucket. # # Note: The following fields are mutually exclusive: `contribution`, `error`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] error # @return [::Google::Rpc::Status] # Output only. The error related to accessing the details about the # contribution of the bucket. # # Note: The following fields are mutually exclusive: `error`, `contribution`. If a field in that set is populated, all other fields in the set will automatically be cleared. class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the contribution of the bucket towards the # `IntelligenceFinding`. # @!attribute [r] top_prefixes # @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution::PrefixContribution>] # Output only. A list of the top object prefixes driving the increase # in cross-region egress. class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the cross-region egress spike details for an object # prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] total_egress_bytes # @return [::Integer] # Output only. The total cross-region egress volume in bytes from the # object prefix. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in cross-region egress for the # object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |
#total_egress_bytes ⇒ ::Integer (readonly)
Returns Output only. The total cross-region egress volume in bytes across the project.
1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1450 class CrossRegionEgressSpike include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the cross-region egress spike details for a bucket. # @!attribute [r] bucket # @return [::String] # Output only. The name of the bucket. # @!attribute [r] total_egress_bytes # @return [::Integer] # Output only. The total cross-region egress volume in bytes for the # bucket. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in cross-region egress for the # bucket. # @!attribute [r] contribution # @return [::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution] # Output only. The details about the contribution of the bucket. # # Note: The following fields are mutually exclusive: `contribution`, `error`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] error # @return [::Google::Rpc::Status] # Output only. The error related to accessing the details about the # contribution of the bucket. # # Note: The following fields are mutually exclusive: `error`, `contribution`. If a field in that set is populated, all other fields in the set will automatically be cleared. class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the contribution of the bucket towards the # `IntelligenceFinding`. # @!attribute [r] top_prefixes # @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution::PrefixContribution>] # Output only. A list of the top object prefixes driving the increase # in cross-region egress. class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the cross-region egress spike details for an object # prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] total_egress_bytes # @return [::Integer] # Output only. The total cross-region egress volume in bytes from the # object prefix. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in cross-region egress for the # object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |