Class: Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution
- Inherits:
-
Object
- Object
- Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/storage/control/v2/storage_control.rb
Overview
Represents the cross-region egress spike details for a bucket.
Defined Under Namespace
Classes: Contribution
Instance Attribute Summary collapse
-
#bucket ⇒ ::String
readonly
Output only.
-
#contribution ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution
readonly
Output only.
-
#error ⇒ ::Google::Rpc::Status
readonly
Output only.
-
#percentage_increase ⇒ ::Float
readonly
Output only.
-
#total_egress_bytes ⇒ ::Integer
readonly
Output only.
Instance Attribute Details
#bucket ⇒ ::String (readonly)
Returns Output only. The name of the bucket.
1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1477 class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the contribution of the bucket towards the # `IntelligenceFinding`. # @!attribute [r] top_prefixes # @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution::PrefixContribution>] # Output only. A list of the top object prefixes driving the increase # in cross-region egress. class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the cross-region egress spike details for an object # prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] total_egress_bytes # @return [::Integer] # Output only. The total cross-region egress volume in bytes from the # object prefix. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in cross-region egress for the # object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#contribution ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution (readonly)
Returns Output only. The details about the contribution of the bucket.
Note: The following fields are mutually exclusive: contribution, error. If a field in that set is populated, all other fields in the set will automatically be cleared.
1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1477 class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the contribution of the bucket towards the # `IntelligenceFinding`. # @!attribute [r] top_prefixes # @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution::PrefixContribution>] # Output only. A list of the top object prefixes driving the increase # in cross-region egress. class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the cross-region egress spike details for an object # prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] total_egress_bytes # @return [::Integer] # Output only. The total cross-region egress volume in bytes from the # object prefix. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in cross-region egress for the # object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#error ⇒ ::Google::Rpc::Status (readonly)
Returns Output only. The error related to accessing the details about the contribution of the bucket.
Note: The following fields are mutually exclusive: error, contribution. If a field in that set is populated, all other fields in the set will automatically be cleared.
1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1477 class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the contribution of the bucket towards the # `IntelligenceFinding`. # @!attribute [r] top_prefixes # @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution::PrefixContribution>] # Output only. A list of the top object prefixes driving the increase # in cross-region egress. class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the cross-region egress spike details for an object # prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] total_egress_bytes # @return [::Integer] # Output only. The total cross-region egress volume in bytes from the # object prefix. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in cross-region egress for the # object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#percentage_increase ⇒ ::Float (readonly)
Returns Output only. The percentage increase in cross-region egress for the bucket.
1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1477 class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the contribution of the bucket towards the # `IntelligenceFinding`. # @!attribute [r] top_prefixes # @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution::PrefixContribution>] # Output only. A list of the top object prefixes driving the increase # in cross-region egress. class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the cross-region egress spike details for an object # prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] total_egress_bytes # @return [::Integer] # Output only. The total cross-region egress volume in bytes from the # object prefix. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in cross-region egress for the # object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#total_egress_bytes ⇒ ::Integer (readonly)
Returns Output only. The total cross-region egress volume in bytes for the bucket.
1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1477 class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the contribution of the bucket towards the # `IntelligenceFinding`. # @!attribute [r] top_prefixes # @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution::PrefixContribution>] # Output only. A list of the top object prefixes driving the increase # in cross-region egress. class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the cross-region egress spike details for an object # prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] total_egress_bytes # @return [::Integer] # Output only. The total cross-region egress volume in bytes from the # object prefix. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in cross-region egress for the # object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |