Class: Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Represents the cross-region egress spike details for a bucket.

Defined Under Namespace

Classes: Contribution

Instance Attribute Summary collapse

Instance Attribute Details

#bucket::String (readonly)

Returns Output only. The name of the bucket.

Returns:

  • (::String)

    Output only. The name of the bucket.



1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1207

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of the top object prefixes driving the increase
  #     in cross-region egress.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the cross-region egress spike details for an object
    # prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] total_egress_bytes
    #   @return [::Integer]
    #     Output only. The total cross-region egress volume in bytes from the
    #     object prefix.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in cross-region egress for the
    #     object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#contribution::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution (readonly)

Returns Output only. The details about the contribution of the bucket.

Note: The following fields are mutually exclusive: contribution, error. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1207

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of the top object prefixes driving the increase
  #     in cross-region egress.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the cross-region egress spike details for an object
    # prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] total_egress_bytes
    #   @return [::Integer]
    #     Output only. The total cross-region egress volume in bytes from the
    #     object prefix.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in cross-region egress for the
    #     object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#error::Google::Rpc::Status (readonly)

Returns Output only. The error related to accessing the details about the contribution of the bucket.

Note: The following fields are mutually exclusive: error, contribution. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Rpc::Status)

    Output only. The error related to accessing the details about the contribution of the bucket.

    Note: The following fields are mutually exclusive: error, contribution. If a field in that set is populated, all other fields in the set will automatically be cleared.



1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1207

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of the top object prefixes driving the increase
  #     in cross-region egress.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the cross-region egress spike details for an object
    # prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] total_egress_bytes
    #   @return [::Integer]
    #     Output only. The total cross-region egress volume in bytes from the
    #     object prefix.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in cross-region egress for the
    #     object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#percentage_increase::Float (readonly)

Returns Output only. The percentage increase in cross-region egress for the bucket.

Returns:

  • (::Float)

    Output only. The percentage increase in cross-region egress for the bucket.



1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1207

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of the top object prefixes driving the increase
  #     in cross-region egress.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the cross-region egress spike details for an object
    # prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] total_egress_bytes
    #   @return [::Integer]
    #     Output only. The total cross-region egress volume in bytes from the
    #     object prefix.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in cross-region egress for the
    #     object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#total_egress_bytes::Integer (readonly)

Returns Output only. The total cross-region egress volume in bytes for the bucket.

Returns:

  • (::Integer)

    Output only. The total cross-region egress volume in bytes for the bucket.



1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1207

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::CrossRegionEgressSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of the top object prefixes driving the increase
  #     in cross-region egress.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the cross-region egress spike details for an object
    # prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] total_egress_bytes
    #   @return [::Integer]
    #     Output only. The total cross-region egress volume in bytes from the
    #     object prefix.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in cross-region egress for the
    #     object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end