Class: Google::Cloud::Storage::Control::V2::IntelligenceFinding::StorageGrowthAboveTrend::BucketContribution
- Inherits:
-
Object
- Object
- Google::Cloud::Storage::Control::V2::IntelligenceFinding::StorageGrowthAboveTrend::BucketContribution
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/storage/control/v2/storage_control.rb
Overview
Represents the storage growth details for a bucket.
Instance Attribute Summary collapse
-
#bucket ⇒ ::String
readonly
Output only.
-
#error ⇒ ::Google::Rpc::Status
readonly
Output only.
-
#percentage_increase ⇒ ::Float
readonly
Output only.
-
#total_storage_growth_bytes ⇒ ::Integer
readonly
Output only.
Instance Attribute Details
#bucket ⇒ ::String (readonly)
Returns Output only. The name of the bucket.
1347 1348 1349 1350 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1347 class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#error ⇒ ::Google::Rpc::Status (readonly)
Returns Output only. The error related to accessing the details about the contribution of the bucket.
1347 1348 1349 1350 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1347 class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#percentage_increase ⇒ ::Float (readonly)
Returns Output only. The percentage increase in storage growth for the bucket.
1347 1348 1349 1350 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1347 class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_storage_growth_bytes ⇒ ::Integer (readonly)
Returns Output only. The total storage growth in bytes for the bucket.
1347 1348 1349 1350 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1347 class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |