Class: Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike
- Inherits:
-
Object
- Object
- Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/storage/control/v2/storage_control.rb
Overview
Represents a finding about a spike in throttled requests (429 errors)
within a project.
This corresponds to the THROTTLED_REQUEST_SPIKE finding type.
Defined Under Namespace
Classes: BucketContribution
Instance Attribute Summary collapse
-
#percentage_increase ⇒ ::Float
readonly
Output only.
-
#throttled_requests ⇒ ::Integer
readonly
Output only.
-
#top_buckets ⇒ ::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution>
readonly
Output only.
Instance Attribute Details
#percentage_increase ⇒ ::Float (readonly)
Returns Output only. The percentage increase in throttled requests across the project.
1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1527 class ThrottledRequestSpike include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the throttled requests details for a bucket. # @!attribute [r] bucket # @return [::String] # Output only. The name of the bucket. # @!attribute [r] throttled_requests # @return [::Integer] # Output only. The count of throttled requests for the bucket. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in throttled requests for the # bucket. # @!attribute [r] contribution # @return [::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution] # Output only. The details about the contribution of the bucket. # # Note: The following fields are mutually exclusive: `contribution`, `error`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] error # @return [::Google::Rpc::Status] # Output only. The error related to accessing the details about the # contribution of the bucket. # # Note: The following fields are mutually exclusive: `error`, `contribution`. If a field in that set is populated, all other fields in the set will automatically be cleared. class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the contribution of the bucket towards the # `IntelligenceFinding`. # @!attribute [r] top_prefixes # @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution>] # Output only. A list of top object prefixes driving the increase in # throttled requests. class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents throttled requests details for an object prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] throttled_requests # @return [::Integer] # Output only. The count of throttled requests for the object prefix. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in throttled requests for the # object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |
#throttled_requests ⇒ ::Integer (readonly)
Returns Output only. The count of throttled requests across the project.
1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1527 class ThrottledRequestSpike include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the throttled requests details for a bucket. # @!attribute [r] bucket # @return [::String] # Output only. The name of the bucket. # @!attribute [r] throttled_requests # @return [::Integer] # Output only. The count of throttled requests for the bucket. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in throttled requests for the # bucket. # @!attribute [r] contribution # @return [::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution] # Output only. The details about the contribution of the bucket. # # Note: The following fields are mutually exclusive: `contribution`, `error`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] error # @return [::Google::Rpc::Status] # Output only. The error related to accessing the details about the # contribution of the bucket. # # Note: The following fields are mutually exclusive: `error`, `contribution`. If a field in that set is populated, all other fields in the set will automatically be cleared. class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the contribution of the bucket towards the # `IntelligenceFinding`. # @!attribute [r] top_prefixes # @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution>] # Output only. A list of top object prefixes driving the increase in # throttled requests. class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents throttled requests details for an object prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] throttled_requests # @return [::Integer] # Output only. The count of throttled requests for the object prefix. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in throttled requests for the # object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |
#top_buckets ⇒ ::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution> (readonly)
Returns Output only. A list of top buckets driving the increase in throttled requests.
1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1527 class ThrottledRequestSpike include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the throttled requests details for a bucket. # @!attribute [r] bucket # @return [::String] # Output only. The name of the bucket. # @!attribute [r] throttled_requests # @return [::Integer] # Output only. The count of throttled requests for the bucket. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in throttled requests for the # bucket. # @!attribute [r] contribution # @return [::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution] # Output only. The details about the contribution of the bucket. # # Note: The following fields are mutually exclusive: `contribution`, `error`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] error # @return [::Google::Rpc::Status] # Output only. The error related to accessing the details about the # contribution of the bucket. # # Note: The following fields are mutually exclusive: `error`, `contribution`. If a field in that set is populated, all other fields in the set will automatically be cleared. class BucketContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the contribution of the bucket towards the # `IntelligenceFinding`. # @!attribute [r] top_prefixes # @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution>] # Output only. A list of top object prefixes driving the increase in # throttled requests. class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents throttled requests details for an object prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] throttled_requests # @return [::Integer] # Output only. The count of throttled requests for the object prefix. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in throttled requests for the # object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |