Class: Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Represents a finding about a spike in throttled requests (429 errors) within a project. This corresponds to the THROTTLED_REQUEST_SPIKE finding type.

Defined Under Namespace

Classes: BucketContribution

Instance Attribute Summary collapse

Instance Attribute Details

#percentage_increase::Float (readonly)

Returns Output only. The percentage increase in throttled requests across the project.

Returns:

  • (::Float)

    Output only. The percentage increase in throttled requests across the project.



1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1257

class ThrottledRequestSpike
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the throttled requests details for a bucket.
  # @!attribute [r] bucket
  #   @return [::String]
  #     Output only. The name of the bucket.
  # @!attribute [r] throttled_requests
  #   @return [::Integer]
  #     Output only. The count of throttled requests for the bucket.
  # @!attribute [r] percentage_increase
  #   @return [::Float]
  #     Output only. The percentage increase in throttled requests for the
  #     bucket.
  # @!attribute [r] contribution
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution]
  #     Output only. The details about the contribution of the bucket.
  #
  #     Note: The following fields are mutually exclusive: `contribution`, `error`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] error
  #   @return [::Google::Rpc::Status]
  #     Output only. The error related to accessing the details about the
  #     contribution of the bucket.
  #
  #     Note: The following fields are mutually exclusive: `error`, `contribution`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class BucketContribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the contribution of the bucket towards the
    # `IntelligenceFinding`.
    # @!attribute [r] top_prefixes
    #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution>]
    #     Output only. A list of top object prefixes driving the increase in
    #     throttled requests.
    class Contribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # Represents throttled requests details for an object prefix.
      # @!attribute [r] prefix
      #   @return [::String]
      #     Output only. The object prefix.
      #     Format: `a/b/c`, 'a/b/d', etc.
      # @!attribute [r] throttled_requests
      #   @return [::Integer]
      #     Output only. The count of throttled requests for the object prefix.
      # @!attribute [r] percentage_increase
      #   @return [::Float]
      #     Output only. The percentage increase in throttled requests for the
      #     object prefix.
      class PrefixContribution
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods
      end
    end
  end
end

#throttled_requests::Integer (readonly)

Returns Output only. The count of throttled requests across the project.

Returns:

  • (::Integer)

    Output only. The count of throttled requests across the project.



1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1257

class ThrottledRequestSpike
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the throttled requests details for a bucket.
  # @!attribute [r] bucket
  #   @return [::String]
  #     Output only. The name of the bucket.
  # @!attribute [r] throttled_requests
  #   @return [::Integer]
  #     Output only. The count of throttled requests for the bucket.
  # @!attribute [r] percentage_increase
  #   @return [::Float]
  #     Output only. The percentage increase in throttled requests for the
  #     bucket.
  # @!attribute [r] contribution
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution]
  #     Output only. The details about the contribution of the bucket.
  #
  #     Note: The following fields are mutually exclusive: `contribution`, `error`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] error
  #   @return [::Google::Rpc::Status]
  #     Output only. The error related to accessing the details about the
  #     contribution of the bucket.
  #
  #     Note: The following fields are mutually exclusive: `error`, `contribution`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class BucketContribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the contribution of the bucket towards the
    # `IntelligenceFinding`.
    # @!attribute [r] top_prefixes
    #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution>]
    #     Output only. A list of top object prefixes driving the increase in
    #     throttled requests.
    class Contribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # Represents throttled requests details for an object prefix.
      # @!attribute [r] prefix
      #   @return [::String]
      #     Output only. The object prefix.
      #     Format: `a/b/c`, 'a/b/d', etc.
      # @!attribute [r] throttled_requests
      #   @return [::Integer]
      #     Output only. The count of throttled requests for the object prefix.
      # @!attribute [r] percentage_increase
      #   @return [::Float]
      #     Output only. The percentage increase in throttled requests for the
      #     object prefix.
      class PrefixContribution
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods
      end
    end
  end
end

#top_buckets::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution> (readonly)

Returns Output only. A list of top buckets driving the increase in throttled requests.

Returns:



1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1257

class ThrottledRequestSpike
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the throttled requests details for a bucket.
  # @!attribute [r] bucket
  #   @return [::String]
  #     Output only. The name of the bucket.
  # @!attribute [r] throttled_requests
  #   @return [::Integer]
  #     Output only. The count of throttled requests for the bucket.
  # @!attribute [r] percentage_increase
  #   @return [::Float]
  #     Output only. The percentage increase in throttled requests for the
  #     bucket.
  # @!attribute [r] contribution
  #   @return [::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution]
  #     Output only. The details about the contribution of the bucket.
  #
  #     Note: The following fields are mutually exclusive: `contribution`, `error`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] error
  #   @return [::Google::Rpc::Status]
  #     Output only. The error related to accessing the details about the
  #     contribution of the bucket.
  #
  #     Note: The following fields are mutually exclusive: `error`, `contribution`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class BucketContribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the contribution of the bucket towards the
    # `IntelligenceFinding`.
    # @!attribute [r] top_prefixes
    #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution>]
    #     Output only. A list of top object prefixes driving the increase in
    #     throttled requests.
    class Contribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # Represents throttled requests details for an object prefix.
      # @!attribute [r] prefix
      #   @return [::String]
      #     Output only. The object prefix.
      #     Format: `a/b/c`, 'a/b/d', etc.
      # @!attribute [r] throttled_requests
      #   @return [::Integer]
      #     Output only. The count of throttled requests for the object prefix.
      # @!attribute [r] percentage_increase
      #   @return [::Float]
      #     Output only. The percentage increase in throttled requests for the
      #     object prefix.
      class PrefixContribution
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods
      end
    end
  end
end