Class: Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Represents the throttled requests details for a bucket.

Defined Under Namespace

Classes: Contribution

Instance Attribute Summary collapse

Instance Attribute Details

#bucket::String (readonly)

Returns Output only. The name of the bucket.

Returns:

  • (::String)

    Output only. The name of the bucket.



1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1283

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of top object prefixes driving the increase in
  #     throttled requests.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents throttled requests details for an object prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] throttled_requests
    #   @return [::Integer]
    #     Output only. The count of throttled requests for the object prefix.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in throttled requests for the
    #     object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#contribution::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution (readonly)

Returns Output only. The details about the contribution of the bucket.

Note: The following fields are mutually exclusive: contribution, error. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1283

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of top object prefixes driving the increase in
  #     throttled requests.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents throttled requests details for an object prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] throttled_requests
    #   @return [::Integer]
    #     Output only. The count of throttled requests for the object prefix.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in throttled requests for the
    #     object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#error::Google::Rpc::Status (readonly)

Returns Output only. The error related to accessing the details about the contribution of the bucket.

Note: The following fields are mutually exclusive: error, contribution. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Rpc::Status)

    Output only. The error related to accessing the details about the contribution of the bucket.

    Note: The following fields are mutually exclusive: error, contribution. If a field in that set is populated, all other fields in the set will automatically be cleared.



1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1283

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of top object prefixes driving the increase in
  #     throttled requests.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents throttled requests details for an object prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] throttled_requests
    #   @return [::Integer]
    #     Output only. The count of throttled requests for the object prefix.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in throttled requests for the
    #     object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#percentage_increase::Float (readonly)

Returns Output only. The percentage increase in throttled requests for the bucket.

Returns:

  • (::Float)

    Output only. The percentage increase in throttled requests for the bucket.



1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1283

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of top object prefixes driving the increase in
  #     throttled requests.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents throttled requests details for an object prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] throttled_requests
    #   @return [::Integer]
    #     Output only. The count of throttled requests for the object prefix.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in throttled requests for the
    #     object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#throttled_requests::Integer (readonly)

Returns Output only. The count of throttled requests for the bucket.

Returns:

  • (::Integer)

    Output only. The count of throttled requests for the bucket.



1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1283

class BucketContribution
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the contribution of the bucket towards the
  # `IntelligenceFinding`.
  # @!attribute [r] top_prefixes
  #   @return [::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution>]
  #     Output only. A list of top object prefixes driving the increase in
  #     throttled requests.
  class Contribution
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents throttled requests details for an object prefix.
    # @!attribute [r] prefix
    #   @return [::String]
    #     Output only. The object prefix.
    #     Format: `a/b/c`, 'a/b/d', etc.
    # @!attribute [r] throttled_requests
    #   @return [::Integer]
    #     Output only. The count of throttled requests for the object prefix.
    # @!attribute [r] percentage_increase
    #   @return [::Float]
    #     Output only. The percentage increase in throttled requests for the
    #     object prefix.
    class PrefixContribution
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end