Class: Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution
- Inherits:
-
Object
- Object
- Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/storage/control/v2/storage_control.rb
Overview
Represents the contribution of the bucket towards the
IntelligenceFinding.
Defined Under Namespace
Classes: PrefixContribution
Instance Attribute Summary collapse
-
#top_prefixes ⇒ ::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution>
readonly
Output only.
Instance Attribute Details
#top_prefixes ⇒ ::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding::ThrottledRequestSpike::BucketContribution::Contribution::PrefixContribution> (readonly)
Returns Output only. A list of top object prefixes driving the increase in throttled requests.
1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1293 class Contribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents throttled requests details for an object prefix. # @!attribute [r] prefix # @return [::String] # Output only. The object prefix. # Format: `a/b/c`, 'a/b/d', etc. # @!attribute [r] throttled_requests # @return [::Integer] # Output only. The count of throttled requests for the object prefix. # @!attribute [r] percentage_increase # @return [::Float] # Output only. The percentage increase in throttled requests for the # object prefix. class PrefixContribution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |