Class: Google::Cloud::Storage::Control::V2::ListIntelligenceFindingsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Response message to list the IntelligenceFinding resources associated with a project.

Instance Attribute Summary collapse

Instance Attribute Details

#intelligence_findings::Array<::Google::Cloud::Storage::Control::V2::IntelligenceFinding>

Returns The IntelligenceFinding resources from the specified project.

Returns:



1426
1427
1428
1429
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1426

class ListIntelligenceFindingsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call.

Returns:

  • (::String)

    A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call.



1426
1427
1428
1429
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1426

class ListIntelligenceFindingsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end