Class: Google::Cloud::Storage::Control::V2::ManagedFolder
- Inherits:
-
Object
- Object
- Google::Cloud::Storage::Control::V2::ManagedFolder
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/storage/control/v2/storage_control.rb
Overview
A managed folder.
Defined Under Namespace
Classes: RapidCacheConfig
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#metageneration ⇒ ::Integer
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#rapid_cache_config ⇒ ::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig
Rapid Cache configuration for a managed prefix.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The creation time of the managed folder.
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 386 class ManagedFolder include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Rapid Cache configuration for a managed prefix. This configuration is used # to determine how the rapid cache behaves for objects under the managed # folder. # @!attribute [rw] policies # @return [::Google::Protobuf::Map{::String => ::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy}] # Optional. A map of rapid_cache_id to RapidCachePolicy for this prefix. # Currently, the key rapid_cache_id is the zone. However, the # field is generalized as rapid_cache_id to align the policy lifetime # with the cache instance lifetime. This allows for a future transition # from zone to a cache id if required. class RapidCacheConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Rapid Cache policy for a managed folder. # @!attribute [rw] rapid_cache_id # @return [::String] # Required. The identifier for the rapid cache. # @!attribute [rw] ingest_on_write # @return [::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy::IngestOnWrite] # Required. If enabled, objects in the Managed Folder will be ingested # into the cache when they are written. class RapidCachePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The behavior of the rapid cache when an object is written. module IngestOnWrite # The behavior is not specified at this resource level. # It should be inherited from the parent resource's configuration. # This is the default value. INGEST_ON_WRITE_UNSPECIFIED = 0 # Ingestion on write is explicitly enabled for this resource. INGEST_ON_WRITE_ENABLED = 1 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy] class PoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#metageneration ⇒ ::Integer (readonly)
Returns Output only. The metadata version of this managed folder. It increases whenever the metadata is updated. Used for preconditions and for detecting changes in metadata. Managed folders don't have a generation number.
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 386 class ManagedFolder include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Rapid Cache configuration for a managed prefix. This configuration is used # to determine how the rapid cache behaves for objects under the managed # folder. # @!attribute [rw] policies # @return [::Google::Protobuf::Map{::String => ::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy}] # Optional. A map of rapid_cache_id to RapidCachePolicy for this prefix. # Currently, the key rapid_cache_id is the zone. However, the # field is generalized as rapid_cache_id to align the policy lifetime # with the cache instance lifetime. This allows for a future transition # from zone to a cache id if required. class RapidCacheConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Rapid Cache policy for a managed folder. # @!attribute [rw] rapid_cache_id # @return [::String] # Required. The identifier for the rapid cache. # @!attribute [rw] ingest_on_write # @return [::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy::IngestOnWrite] # Required. If enabled, objects in the Managed Folder will be ingested # into the cache when they are written. class RapidCachePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The behavior of the rapid cache when an object is written. module IngestOnWrite # The behavior is not specified at this resource level. # It should be inherited from the parent resource's configuration. # This is the default value. INGEST_ON_WRITE_UNSPECIFIED = 0 # Ingestion on write is explicitly enabled for this resource. INGEST_ON_WRITE_ENABLED = 1 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy] class PoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#name ⇒ ::String
Returns Identifier. The name of this managed folder.
Format:
projects/{project}/buckets/{bucket}/managedFolders/{managedFolder}.
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 386 class ManagedFolder include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Rapid Cache configuration for a managed prefix. This configuration is used # to determine how the rapid cache behaves for objects under the managed # folder. # @!attribute [rw] policies # @return [::Google::Protobuf::Map{::String => ::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy}] # Optional. A map of rapid_cache_id to RapidCachePolicy for this prefix. # Currently, the key rapid_cache_id is the zone. However, the # field is generalized as rapid_cache_id to align the policy lifetime # with the cache instance lifetime. This allows for a future transition # from zone to a cache id if required. class RapidCacheConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Rapid Cache policy for a managed folder. # @!attribute [rw] rapid_cache_id # @return [::String] # Required. The identifier for the rapid cache. # @!attribute [rw] ingest_on_write # @return [::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy::IngestOnWrite] # Required. If enabled, objects in the Managed Folder will be ingested # into the cache when they are written. class RapidCachePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The behavior of the rapid cache when an object is written. module IngestOnWrite # The behavior is not specified at this resource level. # It should be inherited from the parent resource's configuration. # This is the default value. INGEST_ON_WRITE_UNSPECIFIED = 0 # Ingestion on write is explicitly enabled for this resource. INGEST_ON_WRITE_ENABLED = 1 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy] class PoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#rapid_cache_config ⇒ ::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig
Returns Rapid Cache configuration for a managed prefix.
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 386 class ManagedFolder include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Rapid Cache configuration for a managed prefix. This configuration is used # to determine how the rapid cache behaves for objects under the managed # folder. # @!attribute [rw] policies # @return [::Google::Protobuf::Map{::String => ::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy}] # Optional. A map of rapid_cache_id to RapidCachePolicy for this prefix. # Currently, the key rapid_cache_id is the zone. However, the # field is generalized as rapid_cache_id to align the policy lifetime # with the cache instance lifetime. This allows for a future transition # from zone to a cache id if required. class RapidCacheConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Rapid Cache policy for a managed folder. # @!attribute [rw] rapid_cache_id # @return [::String] # Required. The identifier for the rapid cache. # @!attribute [rw] ingest_on_write # @return [::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy::IngestOnWrite] # Required. If enabled, objects in the Managed Folder will be ingested # into the cache when they are written. class RapidCachePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The behavior of the rapid cache when an object is written. module IngestOnWrite # The behavior is not specified at this resource level. # It should be inherited from the parent resource's configuration. # This is the default value. INGEST_ON_WRITE_UNSPECIFIED = 0 # Ingestion on write is explicitly enabled for this resource. INGEST_ON_WRITE_ENABLED = 1 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy] class PoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The modification time of the managed folder.
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 386 class ManagedFolder include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Rapid Cache configuration for a managed prefix. This configuration is used # to determine how the rapid cache behaves for objects under the managed # folder. # @!attribute [rw] policies # @return [::Google::Protobuf::Map{::String => ::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy}] # Optional. A map of rapid_cache_id to RapidCachePolicy for this prefix. # Currently, the key rapid_cache_id is the zone. However, the # field is generalized as rapid_cache_id to align the policy lifetime # with the cache instance lifetime. This allows for a future transition # from zone to a cache id if required. class RapidCacheConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Rapid Cache policy for a managed folder. # @!attribute [rw] rapid_cache_id # @return [::String] # Required. The identifier for the rapid cache. # @!attribute [rw] ingest_on_write # @return [::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy::IngestOnWrite] # Required. If enabled, objects in the Managed Folder will be ingested # into the cache when they are written. class RapidCachePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The behavior of the rapid cache when an object is written. module IngestOnWrite # The behavior is not specified at this resource level. # It should be inherited from the parent resource's configuration. # This is the default value. INGEST_ON_WRITE_UNSPECIFIED = 0 # Ingestion on write is explicitly enabled for this resource. INGEST_ON_WRITE_ENABLED = 1 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy] class PoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |