Class: Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/storage/control/v2/storage_control.rb
Overview
Rapid Cache configuration for a managed prefix. This configuration is used to determine how the rapid cache behaves for objects under the managed folder.
Defined Under Namespace
Classes: PoliciesEntry, RapidCachePolicy
Instance Attribute Summary collapse
Instance Attribute Details
#policies ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy}
Returns Optional. A map of rapid_cache_id to RapidCachePolicy for this prefix. Currently, the key rapid_cache_id is the zone. However, the field is generalized as rapid_cache_id to align the policy lifetime with the cache instance lifetime. This allows for a future transition from zone to a cache id if required.
400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 |
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 400 class RapidCacheConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Rapid Cache policy for a managed folder. # @!attribute [rw] rapid_cache_id # @return [::String] # Required. The identifier for the rapid cache. # @!attribute [rw] ingest_on_write # @return [::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy::IngestOnWrite] # Required. If enabled, objects in the Managed Folder will be ingested # into the cache when they are written. class RapidCachePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The behavior of the rapid cache when an object is written. module IngestOnWrite # The behavior is not specified at this resource level. # It should be inherited from the parent resource's configuration. # This is the default value. INGEST_ON_WRITE_UNSPECIFIED = 0 # Ingestion on write is explicitly enabled for this resource. INGEST_ON_WRITE_ENABLED = 1 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Storage::Control::V2::ManagedFolder::RapidCacheConfig::RapidCachePolicy] class PoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |