Class: Google::Cloud::Storage::Control::V2::StorageControl::Rest::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/storage/control/v2/storage_control/rest/client.rb

Overview

REST client for the StorageControl service.

StorageControl service includes selected control plane operations.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#anywhere_cache_path, #bucket_path, #folder_path, #intelligence_config_path, #intelligence_finding_path, #intelligence_finding_revision_path, #location_path, #managed_folder_path, #storage_layout_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new StorageControl REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Storage::Control::V2::StorageControl::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Storage::Control::V2::StorageControl::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the StorageControl client.

Yield Parameters:



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/google/cloud/storage/control/v2/storage_control/rest/client.rb', line 184

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @storage_control_stub = ::Google::Cloud::Storage::Control::V2::StorageControl::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @storage_control_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the StorageControl Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all StorageControl clients
::Google::Cloud::Storage::Control::V2::StorageControl::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/google/cloud/storage/control/v2/storage_control/rest/client.rb', line 65

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Storage", "Control", "V2"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.timeout = 60.0

    default_config.rpcs.get_project_intelligence_config.timeout = 60.0
    default_config.rpcs.get_project_intelligence_config.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 2, retry_codes: [8, 14, 4, 13, 2]
    }

    default_config.rpcs.update_project_intelligence_config.timeout = 60.0
    default_config.rpcs.update_project_intelligence_config.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 2, retry_codes: [8, 14, 4, 13, 2]
    }

    default_config.rpcs.get_folder_intelligence_config.timeout = 60.0
    default_config.rpcs.get_folder_intelligence_config.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 2, retry_codes: [8, 14, 4, 13, 2]
    }

    default_config.rpcs.update_folder_intelligence_config.timeout = 60.0
    default_config.rpcs.update_folder_intelligence_config.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 2, retry_codes: [8, 14, 4, 13, 2]
    }

    default_config.rpcs.get_organization_intelligence_config.timeout = 60.0
    default_config.rpcs.get_organization_intelligence_config.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 2, retry_codes: [8, 14, 4, 13, 2]
    }

    default_config.rpcs.update_organization_intelligence_config.timeout = 60.0
    default_config.rpcs.update_organization_intelligence_config.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 2, retry_codes: [8, 14, 4, 13, 2]
    }

    default_config.rpcs.get_intelligence_finding.timeout = 60.0
    default_config.rpcs.get_intelligence_finding.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 2, retry_codes: [8, 14, 4, 13, 2]
    }

    default_config.rpcs.list_intelligence_findings.timeout = 60.0
    default_config.rpcs.list_intelligence_findings.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 2, retry_codes: [8, 14, 4, 13, 2]
    }

    default_config.rpcs.summarize_intelligence_findings.timeout = 60.0
    default_config.rpcs.summarize_intelligence_findings.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 2, retry_codes: [8, 14, 4, 13, 2]
    }

    default_config.rpcs.get_intelligence_finding_revision.timeout = 60.0
    default_config.rpcs.get_intelligence_finding_revision.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 2, retry_codes: [8, 14, 4, 13, 2]
    }

    default_config.rpcs.list_intelligence_finding_revisions.timeout = 60.0
    default_config.rpcs.list_intelligence_finding_revisions.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 2, retry_codes: [8, 14, 4, 13, 2]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the StorageControl Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



154
155
156
157
# File 'lib/google/cloud/storage/control/v2/storage_control/rest/client.rb', line 154

def configure
  yield @config if block_given?
  @config
end

#get_folder_intelligence_config(request, options = nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig #get_folder_intelligence_config(name: nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig

Returns the Folder scoped singleton IntelligenceConfig resource.

Examples:

Basic example

require "google/cloud/storage/control/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Storage::Control::V2::StorageControl::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Storage::Control::V2::GetFolderIntelligenceConfigRequest.new

# Call the get_folder_intelligence_config method.
result = client.get_folder_intelligence_config request

# The returned object is of type Google::Cloud::Storage::Control::V2::IntelligenceConfig.
p result

Overloads:

  • #get_folder_intelligence_config(request, options = nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig

    Pass arguments to get_folder_intelligence_config via a request object, either of type GetFolderIntelligenceConfigRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Storage::Control::V2::GetFolderIntelligenceConfigRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_folder_intelligence_config(name: nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig

    Pass arguments to get_folder_intelligence_config via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the IntelligenceConfig resource associated with your folder.

      Format: folders/{id}/locations/global/intelligenceConfig

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'lib/google/cloud/storage/control/v2/storage_control/rest/client.rb', line 449

def get_folder_intelligence_config request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Storage::Control::V2::GetFolderIntelligenceConfigRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_folder_intelligence_config..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Storage::Control::V2::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_folder_intelligence_config.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_folder_intelligence_config.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @storage_control_stub.get_folder_intelligence_config request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_intelligence_finding(request, options = nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceFinding #get_intelligence_finding(name: nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceFinding

Gets the IntelligenceFinding for a project.

Examples:

Basic example

require "google/cloud/storage/control/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Storage::Control::V2::StorageControl::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Storage::Control::V2::GetIntelligenceFindingRequest.new

# Call the get_intelligence_finding method.
result = client.get_intelligence_finding request

# The returned object is of type Google::Cloud::Storage::Control::V2::IntelligenceFinding.
p result

Overloads:

  • #get_intelligence_finding(request, options = nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceFinding

    Pass arguments to get_intelligence_finding via a request object, either of type GetIntelligenceFindingRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Storage::Control::V2::GetIntelligenceFindingRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_intelligence_finding(name: nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceFinding

    Pass arguments to get_intelligence_finding via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the IntelligenceFinding resource.

      Format: projects/{project}/locations/{location}/intelligenceFindings/{intelligence_finding}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
# File 'lib/google/cloud/storage/control/v2/storage_control/rest/client.rb', line 781

def get_intelligence_finding request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Storage::Control::V2::GetIntelligenceFindingRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_intelligence_finding..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Storage::Control::V2::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_intelligence_finding.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_intelligence_finding.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @storage_control_stub.get_intelligence_finding request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_intelligence_finding_revision(request, options = nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceFindingRevision #get_intelligence_finding_revision(name: nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceFindingRevision

Gets the IntelligenceFindingRevision resource.

Examples:

Basic example

require "google/cloud/storage/control/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Storage::Control::V2::StorageControl::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Storage::Control::V2::GetIntelligenceFindingRevisionRequest.new

# Call the get_intelligence_finding_revision method.
result = client.get_intelligence_finding_revision request

# The returned object is of type Google::Cloud::Storage::Control::V2::IntelligenceFindingRevision.
p result

Overloads:

  • #get_intelligence_finding_revision(request, options = nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceFindingRevision

    Pass arguments to get_intelligence_finding_revision via a request object, either of type GetIntelligenceFindingRevisionRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Storage::Control::V2::GetIntelligenceFindingRevisionRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_intelligence_finding_revision(name: nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceFindingRevision

    Pass arguments to get_intelligence_finding_revision via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the IntelligenceFindingRevision resource.

      Format:

      projects/{project}/locations/{location}/intelligenceFindings/{intelligence_finding}/revisions/{revision}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
# File 'lib/google/cloud/storage/control/v2/storage_control/rest/client.rb', line 1080

def get_intelligence_finding_revision request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Storage::Control::V2::GetIntelligenceFindingRevisionRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_intelligence_finding_revision..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Storage::Control::V2::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_intelligence_finding_revision.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_intelligence_finding_revision.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @storage_control_stub.get_intelligence_finding_revision request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_organization_intelligence_config(request, options = nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig #get_organization_intelligence_config(name: nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig

Returns the Organization scoped singleton IntelligenceConfig resource.

Examples:

Basic example

require "google/cloud/storage/control/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Storage::Control::V2::StorageControl::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Storage::Control::V2::GetOrganizationIntelligenceConfigRequest.new

# Call the get_organization_intelligence_config method.
result = client.get_organization_intelligence_config request

# The returned object is of type Google::Cloud::Storage::Control::V2::IntelligenceConfig.
p result

Overloads:

  • #get_organization_intelligence_config(request, options = nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig

    Pass arguments to get_organization_intelligence_config via a request object, either of type GetOrganizationIntelligenceConfigRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Storage::Control::V2::GetOrganizationIntelligenceConfigRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_organization_intelligence_config(name: nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig

    Pass arguments to get_organization_intelligence_config via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the IntelligenceConfig resource associated with your organization.

      Format: organizations/{org_id}/locations/global/intelligenceConfig

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
# File 'lib/google/cloud/storage/control/v2/storage_control/rest/client.rb', line 615

def get_organization_intelligence_config request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Storage::Control::V2::GetOrganizationIntelligenceConfigRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_organization_intelligence_config..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Storage::Control::V2::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_organization_intelligence_config.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_organization_intelligence_config.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @storage_control_stub.get_organization_intelligence_config request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_project_intelligence_config(request, options = nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig #get_project_intelligence_config(name: nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig

Returns the Project scoped singleton IntelligenceConfig resource.

Examples:

Basic example

require "google/cloud/storage/control/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Storage::Control::V2::StorageControl::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Storage::Control::V2::GetProjectIntelligenceConfigRequest.new

# Call the get_project_intelligence_config method.
result = client.get_project_intelligence_config request

# The returned object is of type Google::Cloud::Storage::Control::V2::IntelligenceConfig.
p result

Overloads:

  • #get_project_intelligence_config(request, options = nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig

    Pass arguments to get_project_intelligence_config via a request object, either of type GetProjectIntelligenceConfigRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Storage::Control::V2::GetProjectIntelligenceConfigRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_project_intelligence_config(name: nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig

    Pass arguments to get_project_intelligence_config via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the IntelligenceConfig resource associated with your project.

      Format: projects/{id}/locations/global/intelligenceConfig

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/google/cloud/storage/control/v2/storage_control/rest/client.rb', line 283

def get_project_intelligence_config request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Storage::Control::V2::GetProjectIntelligenceConfigRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_project_intelligence_config..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Storage::Control::V2::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_project_intelligence_config.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_project_intelligence_config.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @storage_control_stub.get_project_intelligence_config request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_intelligence_finding_revisions(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Storage::Control::V2::IntelligenceFindingRevision> #list_intelligence_finding_revisions(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Storage::Control::V2::IntelligenceFindingRevision>

Lists all the revisions of an IntelligenceFinding resource.

Examples:

Basic example

require "google/cloud/storage/control/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Storage::Control::V2::StorageControl::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Storage::Control::V2::ListIntelligenceFindingRevisionsRequest.new

# Call the list_intelligence_finding_revisions method.
result = client.list_intelligence_finding_revisions request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Storage::Control::V2::IntelligenceFindingRevision.
  p item
end

Overloads:

  • #list_intelligence_finding_revisions(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Storage::Control::V2::IntelligenceFindingRevision>

    Pass arguments to list_intelligence_finding_revisions via a request object, either of type ListIntelligenceFindingRevisionsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Storage::Control::V2::ListIntelligenceFindingRevisionsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_intelligence_finding_revisions(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Storage::Control::V2::IntelligenceFindingRevision>

    Pass arguments to list_intelligence_finding_revisions via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent of the IntelligenceFindingRevision resource.

      Format:

      projects/{project}/locations/{location}/intelligenceFindings/{intelligence_finding}

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of IntelligenceFindingRevision resources to return.

      The maximum value is 100; values above 100 will be coerced to 100. The default value is 100.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous ListIntelligenceFindingRevisions call. Provide this to retrieve the subsequent page.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
# File 'lib/google/cloud/storage/control/v2/storage_control/rest/client.rb', line 1175

def list_intelligence_finding_revisions request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Storage::Control::V2::ListIntelligenceFindingRevisionsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_intelligence_finding_revisions..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Storage::Control::V2::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_intelligence_finding_revisions.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_intelligence_finding_revisions.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @storage_control_stub.list_intelligence_finding_revisions request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @storage_control_stub, :list_intelligence_finding_revisions, "intelligence_finding_revisions", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_intelligence_findings(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Storage::Control::V2::IntelligenceFinding> #list_intelligence_findings(parent: nil, filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Storage::Control::V2::IntelligenceFinding>

Lists the IntelligenceFinding resources for the specified project.

Examples:

Basic example

require "google/cloud/storage/control/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Storage::Control::V2::StorageControl::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Storage::Control::V2::ListIntelligenceFindingsRequest.new

# Call the list_intelligence_findings method.
result = client.list_intelligence_findings request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Storage::Control::V2::IntelligenceFinding.
  p item
end

Overloads:

  • #list_intelligence_findings(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Storage::Control::V2::IntelligenceFinding>

    Pass arguments to list_intelligence_findings via a request object, either of type ListIntelligenceFindingsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Storage::Control::V2::ListIntelligenceFindingsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_intelligence_findings(parent: nil, filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Storage::Control::V2::IntelligenceFinding>

    Pass arguments to list_intelligence_findings via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent of the IntelligenceFinding resource.

      Format: projects/{project}/locations/{location}

    • filter (::String) (defaults to: nil)

      Optional. The filter expression to be applied. Supports filtering by type and associated_resources.

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of IntelligenceFinding resources to return.

      The maximum value is 100; values above 100 will be coerced to 100. The default value is 100.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous ListIntelligenceFindings call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListIntelligenceFindings must match the call that provided the page token.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
# File 'lib/google/cloud/storage/control/v2/storage_control/rest/client.rb', line 880

def list_intelligence_findings request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Storage::Control::V2::ListIntelligenceFindingsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_intelligence_findings..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Storage::Control::V2::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_intelligence_findings.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_intelligence_findings.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @storage_control_stub.list_intelligence_findings request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @storage_control_stub, :list_intelligence_findings, "intelligence_findings", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


231
232
233
# File 'lib/google/cloud/storage/control/v2/storage_control/rest/client.rb', line 231

def logger
  @storage_control_stub.logger
end

#summarize_intelligence_findings(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Storage::Control::V2::FindingSummary> #summarize_intelligence_findings(parent: nil, resource_scope: nil, filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Storage::Control::V2::FindingSummary>

Summarize the intelligence findings for the specified scope(org, folder or project).

Examples:

Basic example

require "google/cloud/storage/control/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Storage::Control::V2::StorageControl::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Storage::Control::V2::SummarizeIntelligenceFindingsRequest.new

# Call the summarize_intelligence_findings method.
result = client.summarize_intelligence_findings request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Storage::Control::V2::FindingSummary.
  p item
end

Overloads:

  • #summarize_intelligence_findings(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Storage::Control::V2::FindingSummary>

    Pass arguments to summarize_intelligence_findings via a request object, either of type Google::Cloud::Storage::Control::V2::SummarizeIntelligenceFindingsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Storage::Control::V2::SummarizeIntelligenceFindingsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #summarize_intelligence_findings(parent: nil, resource_scope: nil, filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Storage::Control::V2::FindingSummary>

    Pass arguments to summarize_intelligence_findings via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The scope to summarize the findings for. Format:

      • organizations/{organization}/locations/{location}
      • folders/{folder}/locations/{location}
      • projects/{project}/locations/{location}
    • resource_scope (::Google::Cloud::Storage::Control::V2::SummarizeIntelligenceFindingsRequest::ResourceScope) (defaults to: nil)

      Optional. Determines the granularity of the findings when the parent is an organization or folder.

      • PARENT (or not set): A single summary is returned for each insight type, aggregated across the entire parent scope.
      • PROJECT: A separate summary is returned for each insight type for every project within the parent scope.

      The only supported values are PARENT and PROJECT. If no value is specified, the API behaviour defaults to the PARENT.

    • filter (::String) (defaults to: nil)

      Optional. The filter expression, following AIP-160. Supports filtering by FindingType.

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of findings to return.

      The maximum value is 100; values above 100 will be coerced to 100. The default value is 100.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous SummarizeIntelligenceFindings call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to SummarizeIntelligenceFindings must match the call that provided the page token.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
# File 'lib/google/cloud/storage/control/v2/storage_control/rest/client.rb', line 997

def summarize_intelligence_findings request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Storage::Control::V2::SummarizeIntelligenceFindingsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.summarize_intelligence_findings..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Storage::Control::V2::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.summarize_intelligence_findings.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.summarize_intelligence_findings.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @storage_control_stub.summarize_intelligence_findings request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @storage_control_stub, :summarize_intelligence_findings, "finding_summaries", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


164
165
166
# File 'lib/google/cloud/storage/control/v2/storage_control/rest/client.rb', line 164

def universe_domain
  @storage_control_stub.universe_domain
end

#update_folder_intelligence_config(request, options = nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig #update_folder_intelligence_config(intelligence_config: nil, update_mask: nil, request_id: nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig

Updates the Folder scoped singleton IntelligenceConfig resource.

Examples:

Basic example

require "google/cloud/storage/control/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Storage::Control::V2::StorageControl::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Storage::Control::V2::UpdateFolderIntelligenceConfigRequest.new

# Call the update_folder_intelligence_config method.
result = client.update_folder_intelligence_config request

# The returned object is of type Google::Cloud::Storage::Control::V2::IntelligenceConfig.
p result

Overloads:

  • #update_folder_intelligence_config(request, options = nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig

    Pass arguments to update_folder_intelligence_config via a request object, either of type UpdateFolderIntelligenceConfigRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Storage::Control::V2::UpdateFolderIntelligenceConfigRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #update_folder_intelligence_config(intelligence_config: nil, update_mask: nil, request_id: nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig

    Pass arguments to update_folder_intelligence_config via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • intelligence_config (::Google::Cloud::Storage::Control::V2::IntelligenceConfig, ::Hash) (defaults to: nil)

      Required. The IntelligenceConfig resource to be updated.

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      Required. The update_mask that specifies the fields within the IntelligenceConfig resource that should be modified by this update. Only the listed fields are updated.

    • request_id (::String) (defaults to: nil)

      Optional. The ID that uniquely identifies the request, preventing duplicate processing.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
# File 'lib/google/cloud/storage/control/v2/storage_control/rest/client.rb', line 534

def update_folder_intelligence_config request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Storage::Control::V2::UpdateFolderIntelligenceConfigRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_folder_intelligence_config..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Storage::Control::V2::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.update_folder_intelligence_config.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_folder_intelligence_config.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @storage_control_stub.update_folder_intelligence_config request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#update_organization_intelligence_config(request, options = nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig #update_organization_intelligence_config(intelligence_config: nil, update_mask: nil, request_id: nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig

Updates the Organization scoped singleton IntelligenceConfig resource.

Examples:

Basic example

require "google/cloud/storage/control/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Storage::Control::V2::StorageControl::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Storage::Control::V2::UpdateOrganizationIntelligenceConfigRequest.new

# Call the update_organization_intelligence_config method.
result = client.update_organization_intelligence_config request

# The returned object is of type Google::Cloud::Storage::Control::V2::IntelligenceConfig.
p result

Overloads:

  • #update_organization_intelligence_config(request, options = nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig

    Pass arguments to update_organization_intelligence_config via a request object, either of type UpdateOrganizationIntelligenceConfigRequest or an equivalent Hash.

    Parameters:

  • #update_organization_intelligence_config(intelligence_config: nil, update_mask: nil, request_id: nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig

    Pass arguments to update_organization_intelligence_config via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • intelligence_config (::Google::Cloud::Storage::Control::V2::IntelligenceConfig, ::Hash) (defaults to: nil)

      Required. The IntelligenceConfig resource to be updated.

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      Required. The update_mask that specifies the fields within the IntelligenceConfig resource that should be modified by this update. Only the listed fields are updated.

    • request_id (::String) (defaults to: nil)

      Optional. The ID that uniquely identifies the request, preventing duplicate processing.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
# File 'lib/google/cloud/storage/control/v2/storage_control/rest/client.rb', line 700

def update_organization_intelligence_config request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Storage::Control::V2::UpdateOrganizationIntelligenceConfigRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_organization_intelligence_config..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Storage::Control::V2::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.update_organization_intelligence_config.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_organization_intelligence_config.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @storage_control_stub.update_organization_intelligence_config request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#update_project_intelligence_config(request, options = nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig #update_project_intelligence_config(intelligence_config: nil, update_mask: nil, request_id: nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig

Updates the Project scoped singleton IntelligenceConfig resource.

Examples:

Basic example

require "google/cloud/storage/control/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Storage::Control::V2::StorageControl::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Storage::Control::V2::UpdateProjectIntelligenceConfigRequest.new

# Call the update_project_intelligence_config method.
result = client.update_project_intelligence_config request

# The returned object is of type Google::Cloud::Storage::Control::V2::IntelligenceConfig.
p result

Overloads:

  • #update_project_intelligence_config(request, options = nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig

    Pass arguments to update_project_intelligence_config via a request object, either of type UpdateProjectIntelligenceConfigRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Storage::Control::V2::UpdateProjectIntelligenceConfigRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #update_project_intelligence_config(intelligence_config: nil, update_mask: nil, request_id: nil) ⇒ ::Google::Cloud::Storage::Control::V2::IntelligenceConfig

    Pass arguments to update_project_intelligence_config via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • intelligence_config (::Google::Cloud::Storage::Control::V2::IntelligenceConfig, ::Hash) (defaults to: nil)

      Required. The IntelligenceConfig resource to be updated.

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      Required. The update_mask that specifies the fields within the IntelligenceConfig resource that should be modified by this update. Only the listed fields are updated.

    • request_id (::String) (defaults to: nil)

      Optional. The ID that uniquely identifies the request, preventing duplicate processing.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
# File 'lib/google/cloud/storage/control/v2/storage_control/rest/client.rb', line 368

def update_project_intelligence_config request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Storage::Control::V2::UpdateProjectIntelligenceConfigRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_project_intelligence_config..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Storage::Control::V2::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.update_project_intelligence_config.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_project_intelligence_config.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @storage_control_stub.update_project_intelligence_config request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end