Class: Google::Cloud::Storage::Control::V2::SummarizeIntelligenceFindingsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/storage/control/v2/storage_control.rb

Overview

Request message to summarize the intelligence findings for the specified scope(org, folder or project).

Defined Under Namespace

Modules: ResourceScope

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. The filter expression, following AIP-160. Supports filtering by FindingType.

Returns:

  • (::String)

    Optional. The filter expression, following AIP-160. Supports filtering by FindingType.



1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1472

class SummarizeIntelligenceFindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The list of resource scopes.
  module ResourceScope
    # The default behavior. Falls back to PARENT behaviour
    RESOURCE_SCOPE_UNSPECIFIED = 0

    # Summaries are aggregated at the level of the `parent` resource.
    PARENT = 1

    # Summaries are broken down by each project within the `parent` scope.
    PROJECT = 2
  end
end

#page_size::Integer

Returns Optional. The maximum number of findings to return.

The maximum value is 100; values above 100 will be coerced to 100. The default value is 100.

Returns:

  • (::Integer)

    Optional. The maximum number of findings to return.

    The maximum value is 100; values above 100 will be coerced to 100. The default value is 100.



1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1472

class SummarizeIntelligenceFindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The list of resource scopes.
  module ResourceScope
    # The default behavior. Falls back to PARENT behaviour
    RESOURCE_SCOPE_UNSPECIFIED = 0

    # Summaries are aggregated at the level of the `parent` resource.
    PARENT = 1

    # Summaries are broken down by each project within the `parent` scope.
    PROJECT = 2
  end
end

#page_token::String

Returns Optional. A page token, received from a previous SummarizeIntelligenceFindings call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to SummarizeIntelligenceFindings must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous SummarizeIntelligenceFindings call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to SummarizeIntelligenceFindings must match the call that provided the page token.



1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1472

class SummarizeIntelligenceFindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The list of resource scopes.
  module ResourceScope
    # The default behavior. Falls back to PARENT behaviour
    RESOURCE_SCOPE_UNSPECIFIED = 0

    # Summaries are aggregated at the level of the `parent` resource.
    PARENT = 1

    # Summaries are broken down by each project within the `parent` scope.
    PROJECT = 2
  end
end

#parent::String

Returns Required. The scope to summarize the findings for. Format:

  • organizations/{organization}/locations/{location}
  • folders/{folder}/locations/{location}
  • projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The scope to summarize the findings for. Format:

    • organizations/{organization}/locations/{location}
    • folders/{folder}/locations/{location}
    • projects/{project}/locations/{location}


1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1472

class SummarizeIntelligenceFindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The list of resource scopes.
  module ResourceScope
    # The default behavior. Falls back to PARENT behaviour
    RESOURCE_SCOPE_UNSPECIFIED = 0

    # Summaries are aggregated at the level of the `parent` resource.
    PARENT = 1

    # Summaries are broken down by each project within the `parent` scope.
    PROJECT = 2
  end
end

#resource_scope::Google::Cloud::Storage::Control::V2::SummarizeIntelligenceFindingsRequest::ResourceScope

Optional. Determines the granularity of the findings when the parent is an organization or folder.

  • PARENT (or not set): A single summary is returned for each insight type, aggregated across the entire parent scope.
  • PROJECT: A separate summary is returned for each insight type for every project within the parent scope.

The only supported values are PARENT and PROJECT. If no value is specified, the API behaviour defaults to the PARENT.

Returns:

  • (::Google::Cloud::Storage::Control::V2::SummarizeIntelligenceFindingsRequest::ResourceScope)

    Optional. Determines the granularity of the findings when the parent is an organization or folder.

    • PARENT (or not set): A single summary is returned for each insight type, aggregated across the entire parent scope.
    • PROJECT: A separate summary is returned for each insight type for every project within the parent scope.

    The only supported values are PARENT and PROJECT. If no value is specified, the API behaviour defaults to the PARENT.



1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
# File 'proto_docs/google/storage/control/v2/storage_control.rb', line 1472

class SummarizeIntelligenceFindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The list of resource scopes.
  module ResourceScope
    # The default behavior. Falls back to PARENT behaviour
    RESOURCE_SCOPE_UNSPECIFIED = 0

    # Summaries are aggregated at the level of the `parent` resource.
    PARENT = 1

    # Summaries are broken down by each project within the `parent` scope.
    PROJECT = 2
  end
end